package PAR::StrippedPARL::Dynamic;
use 5.006;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut



__DATA__
M?T5,1@$!`0````````````(`*``!````^)L``#0````0M````@``!30`(``(
M`"@`'0`<``$``'!DK@``9"X!`&0N`0"H````J`````0````$````!@```#0`
M```T@```-(`````!`````0``!0````0````#````-`$``#2!```T@0``$P``
M`!,````$`````0````$``````````(````"````0KP``$*\```4`````@```
M`0````"P````L`$``+`!`+0"``#P$@``!@````"````"````#+````RP`0`,
ML`$`0`$``$`!```&````!`````0```!(`0``2($``$B!``!$````1`````0`
M```$````4>5T9```````````````````````````!@````0````O;&EB+VQD
M+6QI;G5X+G-O+C,```0````0`````0```$=.50```````@````8````@````
M!````!0````#````1TY5`-E*L('Z[->W!0X,Z)F%U(UI-K3)80````4````@
M````"@```*`2``@"1A&@P````%8`<1C""``\#0`5$0``$`(`*`````````!8
M(B`*!`H`1(0'J$`(16!I`(0)/D(\EP`!``@A4(`D"6`,@7A)0%H`0`!```$`
M0AL!0(",P(0``A"0$(,)``@!$)")0$#"28`L0)@`0``@`"`$"8"4`>2.EW9(
M!0`````````&````!P````D`````````````````````````"@````P````.
M````$``````````1````$P```!<`````````&0``````````````&@```!T`
M```>````(@```",````D````)@`````````G````*````"P`````````+@``
M`"\````P````,0```#(`````````-``````````X````.0`````````]````
M```````````^````0````$$`````````0@```$,```!%````1P```$H`````
M````30```$X```!/````4````````````````````%,`````````````````
M````````50```%8`````````6`````````!:````7````%X```!?````8```
M````````````80```&4`````````9P````````!I`````````&L```!M````
M`````&\```!P````<0```',```!T````>````%^6DQRC6N^05MN3',..A_\-
M.I<+TE$$A(%T@@UZ\$IK?4&.Q794/)3-/PRO]R/.(-1DU'PA=+`"X%)W*"Y.
M/?9FK\QFV_<`7@:DA_\!KS3HL4B=Y^"G`@K.2J[_S]Y'+>-'Q@%L<X7%[#^0
M`L8.X#T_?I9\-6].WL6)!9!@F.\29TE)(@$C^:2=NY,<?.T1#Z"2:&>&^9R!
M0T75[+J5DQQ;FCL/04V=?'&$,(0M5>O6I]VC:UCOEWFC`&6O#!3BGJ("]AG:
MS>.>!3*EA?NA;&`R8MOMZM/O#L@Y0!^YC?$.Z?O#PDHB??_MWI,<K4OCP-EQ
M6!PKT.$B+`ZQ<QN?UKU8.T`?P^4_+)@BU&BZXY)\(?_D#HJ8W<)N>FGZB]DU
M5Y.M!&(WX_#!0_+OR.;O7WO>A2!/F^A\&-[K(A5/6FC)Q;F<0#"X@@U1&WU?
ML@&+;[_:5QMV;^-PO=!+?6H)0]:?(L>H(6)D!U.I!Y`=`A!1?JF<FV+0^H+L
M+/:+:W^:?-"?+/R'\)9\[@M1^?/;TQV0=8(-0V9+$%Y?=F`%;++-%NI:\3VM
M.0TI_`VHH^#[2>)7Q!A7DEI2_=+O#RS?_DANQ=\?H"(+('V0$.DNQ9NVR-6R
M<=ZKRI]'F`7&`````````````````````,$$`````````````!(````,````
M```````````@````&P``````````````(````-@$`````````````!(```!P
M!```O)L````````2````.@,``&R:````````$@```-$#```8F@```````!(`
M``"U`P``\)H````````2````Z04``*2R`0``````(``8`'4"``!<F```````
M`!(```"N`P``I)L````````2````90(``)29````````$@```"`&``"PQ@``
M0````!(`#0`"!0``M+(!```````0`/'_:`,``%";````````$@```),#``#0
MF0```````!(```!K!0``A,$``+`$```2``T`!@0``%2:````````$@```*P`
M```@F````````!(```!W!```:)@````````2````I04``-BS```P`0``$@`-
M`'D#```\F@```````!(````>!```*)D````````2````$04``/#"`0``````
M$`#Q_TL!```4FP```````!(```"/!0``Y+```-0````2``T`PP4``.B9````
M````$@```%`&```0N```=`D``!(`#0!.!0``L+,``"@````2``T`\P,``"";
M````````$@```#X"``!<FP```````!(```"@`P``:)L````````2````8P,`
M`,B;````````$@```'L!``"DF````````!(```"*!```N+(!``0````A`!D`
M(@,```":````````$@```!`$``!(F@```````!(````I`P``U)L````````2
M````PP,``,29````````$@```*@#``!$F````````!(```"(`0``C)@`````
M```2````FP```*"9````````$@```.\$``"TL@$``````!``\?]"!```L)@`
M```````2````'`,``"2:````````$@```$(#``!,F0```````!(````8`0``
M+)L````````2````^0$``.2:````````$@```(L$``"XL@$`!````"$`&0`<
M!0``\,(!```````0`/'_YP```*B:````````$@```%L%``#8R0``!````!(`
M#0`7`@``U)@````````2````_`4``'#)``!H````$@`-`$D"```PF@``````
M`!(```!=!@``%+<``/P````2``T`[04``/B;````````$@`-`&4%``#`S@``
M`````!(`#@""`P``A)H````````2````]@4```"8````````$@`+`-(```#8
MF@```````!(```#E`P``!)D````````2````O`,``)":````````$@```-@%
M``#(S@``!````!$`#P#V!```M+(!```````0`/'_200``#B;````````$@``
M`"\```"(F0```````!(```!A!```P)H````````2````6`$``*R9````````
M$@```/0%``!0L```-````!(`#0"<`0``.)@````````2````)`4``/#"`0``
M````$`#Q_V\&``"\L0``]`$``!(`#0#X````R)@````````2````40,``,R:
M````````$@```',```#@FP```````!(````(`P``6)D````````2````5P(`
M``R:````````$@````8!``#LFP```````!(````1!@``--(``.I;```1``\`
M/`$``/29````````$@```%X```"8FP```````!(```#E`0``')D````````2
M````/0```+2:````````$@```(D$``"XL@$`!````!$`&0#*`P``X)@`````
M```2````Q0$``.R8````````$@```($%``"TM@``2````!(`#0`0!0``\,(!
M```````0`/'__@,``%"8````````$@```,,```"XF0```````!(```#G!0``
MI+(!```````0`!@`4P0``$2;````````$@```*$$``#`L@$`!````!$`&0!I
M`0``F)@````````2````B@```+";````````$@```+$%``#\M@``&````!(`
M#0"3`@``$)D````````2````@`(``/R:````````$@```(0$``#PQ@``5`(`
M`!(`#0`N!```^)@````````2````H0$``$"9````````$@```"4$```(FP``
M`````!(```">`@``R+(!`!,````1`!D`W@,``-R9````````$@```-@#``"<
MF@```````!(````J`0``<)D````````2````<`,``(R;````````$@```&D$
M``!DF0```````!(```",`@``>)H````````2````TP$``(";````````$@``
M`'P&```(M0``K`$``!(`#0`U!```?)D````````2````I@$``&":````````
M$@```)H#```LF````````!(````G`@``O)@````````2````S`4``#3&``!\
M````$@`-`#P&``"PL@$`!````!$`&`!/````=)L````````2````/04``+BQ
M```$````$@`-`+(!``!TF````````!(````P`@``-)D````````2````#`8`
M`*RR`0`$````$0`8``!L:6)P97)L+G-O`%]?9VUO;E]S=&%R=%]?`%]*=E]2
M96=I<W1E<D-L87-S97,`4&5R;%]S>7-?=&5R;0!097)L7TES=&%T8G5F7W!T
M<@!097)L7W-Y<U]I;FET,P!097)L7TEE>&ET7V9L86=S7W!T<@!097)L7W-A
M=F5?9&5S=')U8W1O<E]X`%!E<FQ?26-O;7!C=E]P='(`4&5R;%]A=&9O<FM?
M;&]C:P!097)L7TEC=7)S=&%C:VEN9F]?<'1R`'!E<FQ?8V]N<W1R=6-T`%!E
M<FQ?8W)O86M?;F]C;VYT97AT`%!E<FQ?27!A<G-E<E]P='(`4&5R;%]A=E]S
M:&EF=`!097)L7W-V7S)P=E]F;&%G<P!097)L7TET;W!?96YV7W!T<@!097)L
M7TET86EN=&5D7W!T<@!097)L7W-V7W-E='!V;@!097)L7VYE=U-6<'8`4&5R
M;%]N97=84U]F;&%G<P!097)L7TEI;E]E=F%L7W!T<@!097)L7TEO<%]P='(`
M4&5R;%])979A;%]R;V]T7W!T<@!P97)L7V9R964`4&5R;%]M9U]S970`4&5R
M;%]A=&9O<FM?=6YL;V-K`%!E<FQ?<W9?<V5T<'8`4&5R;%]'=&AR7VME>5]P
M='(`4&5R;%]'9&]?=6YD=6UP7W!T<@!097)L7TEP97)L7V1E<W1R=6-T7VQE
M=F5L7W!T<@!097)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`4&5R;%]D;W5N=VEN
M9`!097)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`4&5R;%]A=E]F971C:`!B;V]T
M7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L7W-A9F5S>7-M86QL;V,`<&5R
M;%]A;&QO8P!03%]M96UO<GE?=W)A<`!L:6)R97-O;'8N<V\N,@!L:6)N<VPN
M<V\N,0!L:6)D;"YS;RXR`&QI8FTN<V\N-@!L:6)C<GEP="YS;RXQ`&QI8G5T
M:6PN<V\N,0!L:6)P=&AR96%D+G-O+C``<'1H<F5A9%]G971S<&5C:69I8P!C
M;&]S90!O<&5N-C0`7U]E<G)N;U]L;V-A=&EO;@!L<V5E:S8T`')E860`;&EB
M8RYS;RXV`%]?<F5G:7-T97)?871F;W)K`&5X:70`<W1R;F-M<`!?7W-T<F1U
M<`!C;&]S961I<@!?7W-T86-K7V-H:U]F86EL`'5N;&EN:P!M:V1I<@!R96%L
M;&]C`&%B;W)T`&UE;6-H<@!G971P:60`<W1R=&]K`'-T<FQE;@!M96US970`
M<W1R<W1R`')M9&ER`&UE;6-P>0!?7W-T<FYC<'E?8VAK`%]?;'AS=&%T-C0`
M;W!E;F1I<@!?7WAS=&%T-C0`7U]C='EP95]B7VQO8P!G971U:60`<F5A9&QI
M;FL`97AE8W9P`%]?;65M8W!Y7V-H:P!S=')C:'(`<F5A9&1I<C8T`%]?<W!R
M:6YT9E]C:&L`;65M;6]V90!A8V-E<W,`<W1R8VUP`%]?;&EB8U]S=&%R=%]M
M86EN`%]?96YV:7)O;@!L9"UL:6YU>"YS;RXS`%]?<W1A8VM?8VAK7V=U87)D
M`&QI8F=C8U]S+G-O+C$`7U]A96%B:5]U;G=I;F1?8W!P7W!R,`!?7V%E86)I
M7W5N=VEN9%]C<'!?<'(Q`%]E9&%T80!?7V)S<U]S=&%R=`!?7V)S<U]S=&%R
M=%]?`%]?8G-S7V5N9%]?`%]?96YD7U\`7V5N9``O=7-R+VQI8B]P97)L-2]#
M3U)%`'!A<E]C=7)R96YT7V5X96,`<&%R7V)A<V5N86UE`%]?;&EB8U]C<W5?
M9FEN:0!84U]);G1E<FYA;'-?4$%27T)/3U0`<&%R7V5N=E]C;&5A;@!P87)?
M8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V1I<FYA;64`9V5T7W5S97)N86UE7V9R
M;VU?9V5T<'=U:60`<&%R7V-L96%N=7``7TE/7W-T9&EN7W5S960`7U]D871A
M7W-T87)T`'AS7VEN:70`7U]L:6)C7V-S=5]I;FET`&YA;65?;&]A9%]M>5]P
M87)?<&P`6%-?26YT97)N86QS7U!!4E]#3$5!4E-404-+`'-I>F5?;&]A9%]M
M>5]P87)?<&P`<&%R7VUK=&UP9&ER`'!A<E]S971U<%]L:6)P871H`'!A<E]F
M:6YD<')O9P!P87)?:6YI=%]E;G8`1TQ)0D-?,BXT`$=#0U\S+C4``````P``
M`````P`"``0``@`"``$````"`````0`!``(``@`!``(````"``$``@`"``$`
M```!``(``0`!``(````"``(````"``0``@`$``(``@```````0`"``0`!```
M`````@`!`````0````$````!``$``0`"``$````"``(``0`!``(````"````
M`0````$``0````(````$```````!`````````````@`"`````0`!``(````!
M``(`!0```````0```````0`"``(``@````(``@````(``@`"`````0`"````
M`@````$``0````$```````$``0`!`),$```0````(````!1I:0T```4`B08`
M```````!``$`^`(``!`````@````%&EI#0``!`")!@````````$``0"S!```
M$````"````!5)GD+```#`),&`````````0`!`$<#```0`````````!1I:0T`
M``(`B08```````"@L@$`%0(``+BR`0`450``P+(!`!1>``#(L@$`%&@``%BQ
M`0`6$P``7+$!`!9S``!@L0$`%D<``&2Q`0`6*```:+$!`!9:``!LL0$`%@H`
M`'"Q`0`6%```=+$!`!9Y``!XL0$`%@(``'RQ`0`6*0``@+$!`!9?``"$L0$`
M%B(``(BQ`0`6+```C+$!`!9T``"0L0$`%DH``)2Q`0`6-0``F+$!`!96``"<
ML0$`%E<``*"Q`0`690``I+$!`!8^``"HL0$`%F(``*RQ`0`64P``L+$!`!87
M``"TL0$`%GH``+BQ`0`69@``O+$!`!8N``#`L0$`%DT``,2Q`0`6;0``R+$!
M`!9K``#,L0$`%G$``-"Q`0`60P``U+$!`!8,``#8L0$`%BH``-RQ`0`610``
MX+$!`!9;``#DL0$`%B<``.BQ`0`6$```[+$!`!9I``#PL0$`%AL``/2Q`0`6
M40``^+$!`!8D``#\L0$`%DX```"R`0`6!P``!+(!`!8M```(L@$`%C<```RR
M`0`6%@``$+(!`!8E```4L@$`%A(``!BR`0`6<@``'+(!`!8&```@L@$`%FX`
M`"2R`0`6.P``*+(!`!8_```LL@$`%FH``#"R`0`6,P``-+(!`!94```XL@$`
M%D0``#RR`0`62P``0+(!`!8]``!$L@$`%C```$BR`0`6"```3+(!`!9C``!0
ML@$`%F<``%2R`0`6&0``6+(!`!8>``!<L@$`%B\``&"R`0`60@``9+(!`!9=
M``!HL@$`%@\``&RR`0`6'P``<+(!`!8@``!TL@$`%G<``'BR`0`6;P``?+(!
M`!9L``"`L@$`%E(``(2R`0`6"P``B+(!`!9@``",L@$`%@4``)"R`0`6(0``
ME+(!`!8F``"8L@$`%DP``)RR`0`63P``"$`MZ0H!`.L(@+WH!.`MY03@G^4.
MX(_@"/"^Y3`9`0``QH_B$<J,XC#YO.4`QH_B$<J,XBCYO.4`QH_B$<J,XB#Y
MO.4`QH_B$<J,XACYO.4`QH_B$<J,XA#YO.4`QH_B$<J,X@CYO.4`QH_B$<J,
MX@#YO.4`QH_B$<J,XOCXO.4`QH_B$<J,XO#XO.4`QH_B$<J,XNCXO.4`QH_B
M$<J,XN#XO.4`QH_B$<J,XMCXO.4`QH_B$<J,XM#XO.4`QH_B$<J,XLCXO.4`
MQH_B$<J,XL#XO.4`QH_B$<J,XKCXO.4`QH_B$<J,XK#XO.4`QH_B$<J,XJCX
MO.4`QH_B$<J,XJ#XO.4`QH_B$<J,XICXO.4`QH_B$<J,XI#XO.4`QH_B$<J,
MXHCXO.4`QH_B$<J,XH#XO.4`QH_B$<J,XGCXO.4`QH_B$<J,XG#XO.4`QH_B
M$<J,XFCXO.4`QH_B$<J,XF#XO.4`QH_B$<J,XECXO.4`QH_B$<J,XE#XO.4`
MQH_B$<J,XDCXO.4`QH_B$<J,XD#XO.4`QH_B$<J,XCCXO.4`QH_B$<J,XC#X
MO.4`QH_B$<J,XBCXO.4`QH_B$<J,XB#XO.4`QH_B$<J,XACXO.4`QH_B$<J,
MXA#XO.4`QH_B$<J,X@CXO.4`QH_B$<J,X@#XO.4`QH_B$<J,XOCWO.4`QH_B
M$<J,XO#WO.4`QH_B$<J,XNCWO.4`QH_B$<J,XN#WO.4`QH_B$<J,XMCWO.4`
MQH_B$<J,XM#WO.4`QH_B$<J,XLCWO.4`QH_B$<J,XL#WO.4`QH_B$<J,XKCW
MO.4`QH_B$<J,XK#WO.4`QH_B$<J,XJCWO.4`QH_B$<J,XJ#WO.4`QH_B$<J,
MXICWO.4`QH_B$<J,XI#WO.4`QH_B$<J,XHCWO.4`QH_B$<J,XH#WO.4`QH_B
M$<J,XGCWO.4`QH_B$<J,XG#WO.4`QH_B$<J,XFCWO.4`QH_B$<J,XF#WO.4`
MQH_B$<J,XECWO.4`QH_B$<J,XE#WO.4`QH_B$<J,XDCWO.4`QH_B$<J,XD#W
MO.4`QH_B$<J,XCCWO.4`QH_B$<J,XC#WO.4`QH_B$<J,XBCWO.4`QH_B$<J,
MXB#WO.4`QH_B$<J,XACWO.4`QH_B$<J,XA#WO.4`QH_B$<J,X@CWO.4`QH_B
M$<J,X@#WO.4`QH_B$<J,XOCVO.4`QH_B$<J,XO#VO.4`QH_B$<J,XNCVO.4`
MQH_B$<J,XN#VO.4`QH_B$<J,XMCVO.4`QH_B$<J,XM#VO.4`QH_B$<J,XLCV
MO.4`QH_B$<J,XL#VO.4`QH_B$<J,XKCVO.4`QH_B$<J,XK#VO.4`QH_B$<J,
MXJCVO.4`L*#C`."@XP00G>0-(*#A!"`MY00`+>40P)_E!,`MY0P`G^4,,)_E
M$/__ZP;__^O8R0``\,8``'#)```4,)_E%""?Y0,PC^`"()/G``!2XQ[_+P$+
M___J"!4!`%0!```0,)_E`"#3Y0``4N,!(*`#`"##!1[_+^';L@$`(`"?Y0A`
M+>D`,)#E``!3XPB`O0@0,)_E``!3XPB`O0@S_R_A"("]Z`BP`0``````\`\M
MZ07=3>(<P(#B`""@XPU@H.$"$)SG83@AX",TH.'_/,/C830CX`(PAN<$((+B
M0`!2X_;__QH-,*#A`""@XR!0D^4T$)/E"$"3Y0+`EN<!$"7@!!`AX`P0(>`$
M((+BX1^@X0$,4N-`$(/E!#"#XO+__QH00)#E`,"=Y00PD.5\')_E#'"0Y020
MD.4,P(3@!%"=Y6,AH.$!,*#A`1",X`C`D.4)@,?A!5"'X`!PD.4)8`S@!F"(
MX><=@>`'0,SA`("0Y0?``N`(D)#E!G"!X`A@G>4,P(3A`S"%X"!<G^4,,(/@
M!F")X&C!H.'G'8/@!Z#"X6<QH.$%0*#A#'`'X`50AN`,8)WEX5V%X`=PBN$'
M<(7@`8#,X01`AN`04)WE`V`!X-BKG^4&8(CA%)"=Y0(@A.`&((+@"D"@X0J@
MA>#G+8+@81&@X01`B>`,H(K@9\&@X0>`P^$"8,'A#%`"X.*MBN`#,(3@E)N?
MY6)!H.$8()WE!5"&X0%P!^`'<(CA!3"#X`E0H.$)D(+@!W"*X`&@B>`<D)WE
MYSV#X&<1H.$#8,3A`2`#X`50B>`'@,SA`B"&X0S`A>#CK8K@0)N?Y0(@C.!C
MP:#A(#"=Y01P!^`'<(CA"5"@X0F0@^`'<(K@!*")X"20G>7G+8+@9T&@X0)@
MS.$$,`+@!5")X`>`P>$#,(;A`1"%X.*MBN#PFI_E`S"!X&(1H.$H()WE#'`'
MX`=PB.$)4*#A"9""X`=PBN`,H(G@+)"=Y><]@^!GP:#A`V#!X0P@`^`%4(G@
M!X#$X0(@AN$$0(7@XZV*X*":G^4"((3@8T&@X3`PG>4!<`?@!W"(X0E0H.$)
MD(/@!W"*X`&@B>`TD)WEYRV"X&<1H.$%4(G@`F#$X0>`S.$!,`+@#,"%X%B:
MG^4X4)WE!'`'X`,PAN'BK8K@!X"(X0,PC.`)P*#A"9"%X`B`BN!B(:#A!$")
MX#R0G>7H/8/@:&&@X0B@P>$"@`C@`W#"X090`^`,P(G@XTV$X`B@BN$*H(3@
M!5"'X6-!H.$!$(S@0#"=Y>R9G^4%$('@ZLV!X`EPH.%$$)WE"9"#X&I1H.$"
M((G@"I#&X02@"N`'<('@["V"X`H0B>$!$(+@#(#$X04P#.!(()WEJ)F?Y09@
MA^`#,(CA;,&@X0,PAN`)8*#A"9""X$P@G>7A/8/@`:#%X0R``>!A$:#A!F""
MX`-PS.$!L`/@!5"&X`MPA^$$D(G@!W"%X&!)G^504)WE8R&@X0B`BN'C/8G@
M"#"#X`1`A>`!4"+@XWV'X&.!H.$,P(3@`S`EX#"IG^4#,(S@5,"=Y0I0H.$*
MH(S@`L`HX&=AH.'G/8/@!W`LX%C`G>4(D";@!5",X`$0BN`'$('@`B"%X`.0
M*>!CP:#A[$B?Y>,]@>`)$(+@7""=Y>,=@>`$0(+@!B`LX&-1H.$(@(3@`S`B
MX`R@)>#`>)_E`S"(X&%!H.'A/8/@8("=Y0&@*N!D$)WE!R"@X0(@@>`'<(C@
M!G"'X`6`).`,((+@C&B?Y6C`G>5C$:#A"G"'X`.`*.`$H"'@XSV'X`9@C.`(
M((+@XRV"X&/!H.$%@(;@`S`JX%AXG^4!H"S@`S"(X&)AH.'B/8/@;("=Y0*@
M*N!P()WE!U"@X050@N`'<(C@!'"'X`R`)N`!$(7@($B?Y710G>5C(:#A"G"'
MX`.`*.`&H"+@XSV'X`1`A>`($('@XQV!X&-1H.$,@(3@`S`JX.QWG^4"H"7@
M`S"(X&'!H.'A/8/@>("=Y0&@*N!\$)WE!T"@X01`@>`'<(C@!F"'X`6`+.`"
M((3@M'>?Y8!`G>5C$:#A"F"&X`.`*.`,H"'@XSV&X`=PA.`(((+@8T&@X>,M
M@N`%@(?@`S`JX(!GG^4#,(C@A("=Y09PH.$&8(C@#*"&X(C`G>5B4:#A`8`D
MX.(]@^`'<(S@`B`HX`2`)>`!$(?@`B"*X`.`*.!CP:#AXRV"X#AGG^4(,('@
MC!"=Y06@+.`&8('@XCV#X&(1H.$$@(;@`B`JX!1WG^4,H"'@`B"(X)"`G>7C
M+8+@8T&@X0.@*N"4,)WE!V"@X0=PB.`%<(?@!F"#X`&`).`,P(;@"J"'X`*`
M*.!B,:#AXJV*X,Q6G^4(((S@F,"=Y01@(^`%4(S@"F`FX`%0A>`&4(7@K':?
MY9Q@G>5JP:#AZBV"X`=PAN`#@"S@!$"'X`*`*.!B$:#A"*"$X(AFG^6@0)WE
M#'"!X>)=A>`%@`?@!F"$X`QP`>`#8(;@!W"(X64AH.%@1I_EY5V*X`>@AN"D
M8)WE`8""X06`".`!<`+@!$"&X`Q`A.`'<(CA93&@X31FG^7E78K@!Z"$X*A`
MG>4"@(/A!8`(X`)P`^`&8(3@`6"&X`=PB.%EP:#A"$:?Y>5=BN`'H(;@K&"=
MY0.`C.$%@`C@`W`,X`1`AN`"0(3@!W"(X641H.'<99_EY5V*X`>@A."P0)WE
M#("!X06`".`,<`'@!F"$X`-@AN`'<(CA92&@X;!%G^7E78K@!Z"&X+1@G>4!
M@(+A!8`(X`%P`N`$0(;@#$"$X`=PB.%E,:#AA&6?Y>5=BN`'H(3@N$"=Y0*`
M@^$%@`C@`G`#X`9@A.`!8(;@!W"(X67!H.%819_EY5V*X`>@AN"\8)WE`X",
MX06`".`#<`S@!$"&X`)`A.`'<(CA91&@X2QEG^7E78K@!Z"$X,!`G>4,@('A
M!8`(X`QP`>`&8(3@`V"&X`=PB.%E(:#A`$6?Y>5=BN`'H(;@Q&"=Y0&`@N$%
M@`C@`7`"X`1`AN`,0(3@!W"(X64QH.'49)_EY5V*X`>@A.#(0)WE`H"#X06`
M".`"<`/@!F"$X`%@AN`'<(CA9<&@X:A$G^7E78K@!Z"&X,Q@G>4#@(SA!8`(
MX`-P#.`$0(;@`D"$X`=PB.%E$:#A?&2?Y>5=BN`'H(3@T$"=Y0R`@>$%@`C@
M#'`!X`9@A.`#8(;@!W"(X64AH.%01)_EY5V*X`>@AN#48)WE`8""X06`".`!
M<`+@!$"&X`Q`A.`'<(CA93&@X21DG^7E78K@!Z"$X-A`G>4"@(/A!8`(X`)P
M`^`&8(3@`6"&X`=PB.%EP:#A^$.?Y>5=BN`'H(;@W&"=Y0.`C.$%@`C@`W`,
MX`1`AN`"0(3@!W"(X641H.',8Y_EY5V*X`>@A.#@0)WE#("!X06`".`,<`'@
M!F"$X`-@AN`'<(CA92&@X:!#G^7E78K@!Z"&X.1@G>4!@(+A!$"&X`6`".`!
M8`+@#,"$X`9@B.%E,:#A='.?Y>5=BN`&H(S@Z,"=Y0*`@^$'<(S@!8`(X`+`
M`^`!$(?@#,"(X65!H.$,P('@1&.?Y>P0G>7E78K@`W"$X09@@>`%@`?@`Q`$
MX`&`B.$"((;@)'.?Y0@@@N#P@)WEY<V,X&51H.$'$*#A!W"(X`2`)>!L8:#A
M["V"X`,PA^`,<"C@],"=Y06@)N`!$(S@!!"!X`<P@^`"H"K@8L&@X>(]@^#4
M@I_E"B"!X/@0G>4&0"S@"("!X.,M@N!C$:#A!8"(X`,P).`,H"'@K'*?Y0,P
MB.!B4:#AXCV#X/R`G>4"H"K@`"&=Y0=`H.$$0(+@!W"(X`9PA^`!@"7@#,"$
MX'ABG^4$09WE8R&@X0IPA^`#@"C@!:`BX.,]A^`&8(3@",",X./-C.!C0:#A
M`8"&X`,P*N!$<I_E`J`DX`,PB.!L8:#A[#V#X`B!G>4,H"K@#,&=Y0<0H.$!
M$(S@!W"(X`5PA^`$@";@`B"!X`Q2G^40$9WE8\&@X0IPA^`#@"C@!J`LX.,]
MA^`%4('@""""X.,M@N!C$:#A!("%X`,P*N#8<9_E#*`AX`,PB.!B4:#AXCV#
MX!2!G>4"H"K@&"&=Y0=`H.$$0(+@!W"(X`9PA^`!@"7@#,"$X*!AG^4<09WE
M8R&@X0IPA^`#@"C@!:`BX.,]A^`&8(3@",",X./-C.!C0:#A`8"&X`,P*N!L
M<9_E`J`DX`,PB.!L$:#A[#V#X""!G>4,H"K@),&=Y0=@H.$&8(S@!W"(X`5P
MA^`$@"'@`B"&X#11G^4H89WE8\&@X0IPA^`#@"C@`:`LX.,]A^`%4(;@""""
MX.,M@N!C8:#A!("%X`,P*N``<9_E`S"(X"R!G>4,H";@!U"@X0=PB.#B/8/@
M8D&@X0*@*N`!$(?@,"&=Y0:`).`*$('@XQV!X`50@N`#@"C@8R&@X;QPG^4T
M,9WE#,"%X`=P@^`(P(S@!(`BX`9@A^`!<"C@`)"0Y9A0G^4'<(;@/*&=Y3AA
MG>7AS8S@83&@X6R!H.$%$*#A"J")X`50AN`"8"/@['V'X`1`A>`!$(K@`U`H
MX`S`)N`,P(3@`B"!X`=0)>`$$)#EY\V,X`4@@N#L+8+@"$"0Y0'`C.`,D)#E
M$!"0Y6=QA.`)@(C@`3"#X`00@.@(<(#E#("`Y1`P@.4%W8WB\`^]Z![_+^&9
M>8):H>O9;MR\&X_6P6+*^$4MZ0!04.(!H*#A!0"@`?B%O0BH,)_E`("3Y0``
M6.,(`*`!^(6]"`!PU>4]`%?C``!7$P!PH`,!<*`3!@``"@$PA>(#<*#A`2#3
MY#T`4N,``%(3^O__&@=P9>``0)CE``!4XQ0```H(8*#A!`"@X040H.$'(*#A
M1OS_ZP``4.,"```:!S#4YST`4^,$```*!$"VY0``5./S__\:!`"@X?B%O>@&
M8&C@1F&@X0$`A^(`8(KE``"$X/B%O>@$`*#A^(6]Z+BR`0`$X"WE#-!-X@00
MC>+)___K#-"-X@"`O>AP0"WI"-!-X@!0H.$$0(WB!0"@X000H.'`___K/&"?
MY0``4.,+```*`#"6Y00@G>4",8/@!""3Y00@@^0``%+C^___&@4`H.$$$*#A
ML___ZP``4./S__\:"-"-XG"`O>BXL@$`.$`MZ0``H.,=_/_K``"0Y9'[_^M"
M^__K`#"0Y0``H.,$0)/E%OS_ZP``D.6*^__K6?O_ZP!0T.4``*#C$/S_ZW]0
M!>(``)#E@_O_ZU7[_^L`,)#E``"@X[`QT^&#.Z#A(UB%X;)0Q.$%_/_K``"0
MY7G[_^LJ^__K`#"0Y0``H.,$0)/E_OO_ZP``D.5R^__K'!&?Y0`@H./>^__K
M'`"$Y0``H./V^__K``"0Y6K[_^L;^__K`#"0Y0``H.,$0)/E[_O_ZP``D.5C
M^__K+_O_ZP`PD.4@,(3E``"@X^C[_^L``)#E7/O_ZPW[_^L`,)#E``"@XP1`
MD^7A^__K``"0Y57[_^NH^__K`#"0Y0``4^,&```*``"@X]G[_^L``)#E3?O_
MZZ#[_^L`,)#E;#"3Y20PA.4``*#CT?O_ZP!`H.,``)#E1/O_Z_7Z_^L`,)#E
M!`"@X00PD^4H0(/ER/O_ZP``D.4\^__K[?K_ZP`PD.4$`*#A!#"3Y1A`@^7`
M^__K``"0Y33[_^OE^O_K`#"0Y00`H.$$0)/EN?O_ZP``D.4M^__KH?O_ZP`P
MD.4L,(3E.("]Z,C0``#P02WI`$!0XG#03>("```*`##4Y0``4^,!```:<-"-
MXO"!O>C<^O_K`&!0X@B`C1+Y__\*!@"@X9'[_^L`,%#B$U"#X@0`H.$C```*
M$R#3Y2X`4N,E```*+/O_ZP!PH.$%`*#A*?O_ZP``A^`"`(#B4_O_ZZ`PG^4!
M$*#C`"#@XS``C>@`<*#A@/O_ZP<0H.$((*#A`P"@XT#[_^L!`'#C!P"@X0,`
M``H8,)WE#SH#X@$)4^,6```*%_O_ZP<`H.'Q^O_K!@"@X6W[_^L`,%#B$U"#
MX@0`H.';__\:!@"@X2C[_^L$`*#A/OO_Z\K__^H4(-/E``!2X\W__PHN`%+C
MU/__&A4PT^4``%/CR/__"M#__^JY___KY___ZD#/```X0"WI`$"@X0``H.-F
M^__K``"0Y=KZ_^LP^__K!!"@X0`@H.$#`*#C1_O_ZP!04.(``*`3.("]&%O[
M_^L``)#ES_K_ZR7[_^L0,)#E#SH#X@$)4^,*```*!0"@X5+[_^L``)#EQOK_
MZQS[_^L0,)#E#SH#X@H*4^,!```*!0"@X3B`O>@$`*#A`A"@X[_Z_^L!`'#B
M``"@,SB`O>CP3RWI`##1Y0%`H.$]`%/C`4"!`@S03>(`8*#A!`"@X<OZ_^L$
M$(WB`'"@X08`H.'$_O_K`%!0X@H```K$^O_K``!7X0`PH)->``"*`P#4YP,`
MQ><``%#C`3"#XOK__QH,T(WB\(^]Z&B!G^4`L)CE`#";Y0``4^,($*`#`U"@
M`08```H+,*#A!""SY0%0A>(``%+C^___&@(0A>(!$:#A-#&?Y0`@D^4``%+C
M"```"@L`H.$/^__K``!0XP"@H.$``(CE!9&@$0P``!H``.#CXO__Z@$@H.,!
M`*#A`""#Y<CZ_^L`H%#B]___"@61H.$+$*#A"2"@X=3Z_^L`H(CE`3"%X@`@
MH.,#(8KG!%"-Y0`PUN4]`%/C``!3$P80H`$%```*`3"&X@,0H.$!(-/D/0!2
MXP``4A/Z__\:`1!FX`(`A^(!`(#@`%"8Y:WZ_^L``%#C"0"%Y]O__PIT,)_E
M!!"=Y0`@D^4`,-;E`1&2YP``4^,`,,'E"@``"CT`4^,(```*`2"!X@$``.H]
M`%/C!```"@$P]N4"$*#A``!3XP$PPN3X__\:/2"@XP$PH.$`(,'E`0#4Y`$`
MX^4``%#C^___&J7__^H$D)WE!("?Y0F1H.'-___JN+(!`-RR`0`00"WI``"@
MX\CZ_^L``)#E//K_ZPP0G^4,()_E##"?Y1!`O>BX^O_J2,\``)29``!DSP``
M!.`MY0``H.,,T$WBNOK_ZP``D.4N^O_KZ___ZP``H..U^O_K``"0Y2GZ_^L@
MP)_E`,"-Y0PPH.$8$)_E`,"@XQ0@G^4$P(WE-OK_ZPS0C>(`@+WHR-```'#/
M``"$P0``\$`MZ;A`G^4"VDWB'-!-X@`PE.4"*HWB%#""Y7KZ_^L!6HWB&%"%
MX@A01>*4P)_E`1"@XY`@G^60,)_E`1"-Z`4`H.&%^O_K``!0XPD``*H`4*#C
M`CJ-XA0@D^4`,)3E!0"@X0,`4N$4```:'-"-X@+:C>+P@+WH&&"-X@Q@1N(%
M`*#A!A"@X0$JH.-D^O_K`'!0XNW__[H!`(?B//K_ZP!04.+J__\*!A"@X0<@
MH.$0^O_K`#"@XP<PQ>?D___J-OK_Z\"R`0"4SP```1```(C/``#)___J\$\M
MZ<@AG^4!VDWB'-!-X@`PDN4!RHWB`'"@X10PC.6P`9_E`4"@X27^_^LO$*#C
M`&"@X0<`H.&M^?_K`%!0X@P```H'$*#AC`&?Y1C__^M\P9_E`1J-XA0@D>4`
M,)SE!P"@X0,`4N%8```:'-"-X@':C>+PC[WH!P"@X>'Y_^M8$9_E`+"@X00`
MH.$0^O_K`$!0XCT```H8@(WB0*&?Y4"1G^4!L(OB!(!(X@`PU.4``%/C"D"@
M`0``5N,$```*!@"@X000H.%,^O_K``!0XRD```H$`*#AROG_ZP`PA.`!(%/E
M+P!2XP0``!H!4&/E`2!3Y0$`0.(O`%+C^O__"@``B^`)`%#AS?__RMC`G^4!
M$*#C`2J@X]`PG^4(`*#A$!"-Z`APC>46^O_K``"@XR/Z_^L``)#EE_G_Z^WY
M_^L($*#A`""@X0,`H./1^?_K``!0XP<``!H9^O_K``"0Y8WY_^OC^?_K$#"0
MY0\Z`^(""5/C"0``"@``H.-<$)_ET_G_ZP``4.,`0*#AQO__&@<0H.%``)_E
MQ?[_ZZO__^H(`*#A`1"@XW[Y_^L``%#C\/__&@@0H.$<`)_EO/[_ZP@`H.$!
M^O_K`'"@X9___^J\^?_KP+(!`)S/``"HSP``N,\``)C/``#_#P``Q,\``+S/
M````,-#E``!3XQ[_+P$!((#B+P!3XP(`H`$!,-+D``!3X_K__QH>_R_A$$`M
MZ0!`4.(:```*`##4Y0``4^,7```*<_G_ZP$`0.(`((3@`@!4X0H``"H`,-3G
M+P!3XRP``!H!,$+B`@``Z@$04^0O`%'C)P``&@,`5.$#(*#A^?__.@0`4N$.
M```:`##2Y2\`4^,H```*L`"?Y1!`O>C.^?_J`@"@XX?Y_^L``%#C`#"@X14`
M``H"(*#CD!"?Y1!`O>A9^?_J`3!"X@,`5.$#(*#A`@``*@$04^0O`%'C^?__
M"@(@9.`",(+B`0I3XP`PH(,%``"*`3J@XU0`G^4$$*#A`2""XA+Y_^M$,)_E
M`P"@X1"`O>@!,$+B`@``Z@$04^0O`%'CU?__"@,`5.$#(*#A^?__.M'__^H"
M`*#C8?G_ZP`P4.+:__\:[___ZL3/``"8SP``X+(!`#!`+>E(X9_E+-!-X@\`
MON@-P*#A#P"LZ`\`ON@T49_E#P"LZ``PE>4D,(WE*`&?Y;#@WN&PX,SA5/W_
MZQP!G^52_?_K&`&?Y5#]_^L4`9_E3OW_ZQ`!G^5,_?_K#`&?Y4K]_^L(`9_E
M2/W_ZP0!G^5&_?_K``&?Y43]_^O\`)_E0OW_Z_@`G^5`_?_K]`"?Y3[]_^OP
M`)_E//W_Z^P`G^4T_?_K#4"@X0`04.(!```*Q`"?Y2O^_^O4`)_E+?W_ZP`0
M4.(!```*R`"?Y27^_^O$`)_E)_W_ZP`04.(*```*C`"?Y1_^_^M\`)_EK!"?
MY1S^_^LD()WE`#"5Y0,`4N$2```:+-"-XC"`O>B0`)_E&/W_ZP`04.("```*
M5`"?Y1#^_^OO___J$0"$XG00G^4*(*#C0_G_ZP``4./I__\:&Q"$XBP`G^4&
M_O_KY?__Z@GY_^O0S@``P+(!`,C/``#4SP``W,\``.C/``#PSP```-```)S/
M```,T```&-```"30``"HSP``,-```#S0``!(T```7-```'#0``!\T```K-``
M`(S0``"@T```$$`MZ31`G^4``)3E`0!PXQ"`O1@H`)_EZ_S_ZP``4.,$```*
M``#0Y0``4.,!```*,`!0X@$`H!,``(3E$("]Z*BR`0`,T```"$`MZ8CX_^NW
M^/_K``!0XP``D!4(@+WHZ,"?Y?!%+>D`<*#A+-!-X@\`O.@04(WB!4"@X0\`
MI.@#`)SH!#"@X1!`G>4#`(/H`##4Y0``4^,7```*L("?Y08``.JN^/_K``!0
MXQ0```H$0+7E`##4Y0``4^,.```*!`"@X<#\_^L'$*#A`&!0X@(```H`,-;E
M``!3X_#__QH$`*#A!Q"@X;/]_^L$0+7E`##4Y0``4^/P__\:+-"-XO"%O>@'
M`*#A@/C_ZP"@H.$&`*#A??C_ZP``BN`"`(#BI_C_ZP$0H.,`(.#C)#"?Y8`!
MC>@(8(WE`*"@X=/X_^L$`*#A"A"@X9O]_^O7___J],X``+C/``"\SP``\$\M
MZ0!)G^6!W$WB`*"@X0\`E.@TT$WB$."$XG#`C>(/`(SH#P"^Z%C`C>(/`*SH
M`P">Z"A`A.(#`(SH!P"4Z,A(G^6`,(WB`,"4Y0*)C>('`(/H+,&(Y;0(G^6#
M_/_K`$!0X@(```H`,-3E``!3X\H!`!J<___K`(!0XLX!``H`0-CE``!4XPH`
M``II^/_K"#"@X5\0H.,`()#EA$"@X;0@DN$(`!+C`!##!0%`\^4``%3C]___
M&E@XG^6![(WB,.".X@,`GN<`,-#E``!3XX@!``H!4*#C"0``ZH$,C>(P`(#B
M!3&`X`(Y0^+8,$/B``"3Y0%0A>(`,-#E``!3XWP!``I9_/_K`$!0XO+__PHK
M_?_K``!0X^___PH$`*#AE?C_ZP!`4.+K__\*!`"@X1_X_^O@=Y_E`&"@X0@`
MH.$;^/_K`&"&X`%KAN($8(;B!@"@X4/X_^L`4*#A!@"@X4#X_^NTQY_E`"#@
MX[`WG^4!$*#CD!"-Z`R`C>4`8*#A:_C_ZYP7G^4&`*#AHO?_ZY0'G^4U_/_K
M*%"-Y0``4..#`0`*`$":Y7/X_^L`$*#A!`"@X?S]_^L`0%#B?`$`"@0`H.'Z
M]__K`P!0XP"`H.$+``#:!`!`X@``A.!,%Y_E<?C_ZP``4.,%```:!`!8XUP!
M``H(@(3@!3!8Y2\`4^-8`0`*)O__ZP`04.(T```*'!>?Y1P'G^40_?_K+_C_
MZQ2'G^4!$*#C`"#@XPPWG^7``(WH#("-Y0!`H.,(`(WE!0"@X3KX_^L.``#J
M7/C_ZP`PD.41`%/C$```&A_X_^L!0(3B`1"@XPH@H.'0-I_EP`"-Z`Q`C>40
M@(WE"`"-Y04`H.$J^/_K!0"@X906G^5A]__K`0!PXP"@H.'J__\*!@"@X:'W
M_^MD!I_E!1"@X>K\_^L%`*#A$?__ZTR6G^4"B8WB+"&8Y0`PF>4H`)WE`P!2
MX8L!`!I-WXWB`MF-XO"/O>@$`*#AP/?_ZP`@4.(D((WEQ?__"@`PX.,1(.#C
M`D"@XP!`C>73]__K)`"=Y8P0C>(&(*#CA_?_ZX&,C>(@-I_E,("(X@,PV.<`
M`%/C`@``&HTPW>5#`%/C4P$`"@!`H.,`,*#C)`"=Y0`@H.,`0(WEP/?_Z^PU
MG^4"R8WBC#",Y2(S@^(B-X/B(CN#XH@P@^("F8WBD#",Y<PUG^6,D(GBE#",
MY0*YC>+`-9_EF#",Y1S@B>*X-9_EJ+"+X@6@H.$&@*#AG#",Y:!`C.6D0(SE
MZ$",Y2S@C>4D`)WEC!"-X@(IH.-;]__K`$!0XD0``-H""8WBH""0Y0+IC>*$
M,8+@`P!2X0+)C8*D()R%`!"@D:0@D97H`)[E`2""@J0N@N```%#CH#".Y:0@
MCN6,8(T"$P``"BP0G>5`8&#B!@!4X01@H+$&8*"A``"!X`8@H.&,$(WB8_?_
MZP(IC>+H,)+E`S"&X$``4^/H,(+EV?__&HPPC>()`*#A!$!FX`9@@^`*^/_K
M/P!4XQ```-H`4*#C!1"&X$`@H.,+`*#A4??_ZT!0A>()`*#A`/C_ZP0P9>`_
M`%/C]?__RD!`1.(D,Z#A`2"#X@,]8^`"8X;@`T.$X`0@H.$&$*#A1#"@XRP`
MG>4H]__K`LF-XNA`C.4D`)WEC!"-X@(IH.,6]__K`$!0XKK__\HD`)WE2/?_
MZP+IC>*@0)[E@0R-XJ0AH.$_(`+B`3""XC``@.("((#@?Q#@XS@`4^,(8*#A
M"E"@X:2`GN6($$+EP```RAP`B>(#`(#@`!"@XS@@8^+C]O_K*,R@X2@8H.$H
M)*#A).R@X20TH.$DJ*#A"0"@X0*9C>+@P,GEX1#)Y>(@R>7C@,GEY.#)Y>6@
MR>7F,,GEYT#)Y</W_^L"R8WBD`"<Y900G.4@B*#AF""<Y2R`C>4AC*#AG#"<
MY2!,H.$T@(WE(82@X21`C>4\@(WE($2@X2*(H.&,X)SE,$"-Y42`C>4A2*#A
M(XR@X3A`C>5,@(WE(DR@X2.$H.$NF*#A0$"-Y52`C>4B1*#A@8R-XAF0R.5(
M0(WE))"=Y2-(H.$;X,CE')#(Y2[,H.$PD)WE+K2@X5!`C>4LX)WE@4R-XAW@
MR.4>D,CE'P#(Y33@G>4X`)WE&$"$XCR0G>4@X,CE(0#(Y1Q`C>48P,CE&K#(
MY2*0R.5`X)WE(Q#(Y23@R.4G(,CE`JF-XD0`C>('`I#H5."=Y24`R.4F$,CE
M*"#(Y2F0R.4JX,CE*S#(Y0!`H./LH(KB'("=Y0```.H!P/CE!`"*X`$0H.,`
M(.#CH#*?Y0)`A.(`P(WE&_?_ZR@`5./U__\:`,"@XX%,C>(4P,3E!0"@X5C"
MG^4!$*#C`"#@XW`RG^7`%(WH#_?_Z^G^_^ID,I_E@<R-XC#`C.(#4)SG`$#5
MY0``5.,!8*`3"@``&H/^_^J!'(WB,!"!X@8Q@>`".4/BP#!#X@!0D^4!8(;B
M`$#5Y0``5.-Y_O\*!0"@X9W[_^L``%#C\?__"@4`H.$']__K`$!0XNW__PIP
M_O_J!(":Y0``6..C_O\*"`"@X8WV_^L#`%#CG_[_F@0`0.(``(C@U!&?Y07W
M_^L``%#C"$"@`9C^_^K7_?_K!`"@X?/V_^LH`(WEP?[_Z@!`FN6`_O_JJ#&?
MY8&<C>(PD(GB`P"9YP`PT.4``%/C$P``"@%`H.,)``#J@<R-XC#`C.($,8S@
M`CE#XK`P0^(``)/E`4"$X@`PT.4``%/C!P``"ICZ_^L``%#C\O__"MCV_^L`
M`%#C[___"@"`H.$5_O_J0(&?Y2'^_^H<`(GB`!"@XT`@8^(#`(#@(O;_ZPD`
MH.$1]__K`#"@XP(9C>*H,('EK#"!Y;`P@>6T,('EN#"!Y;PP@>7`,('EQ#"!
MY<@P@>7,,('ET#"!Y=0P@>78,('EW#"!Y2O__^J.,-WE00!3XZC^_QJ/,-WE
M0P!3XZ7^_QJ0,-WE2`!3XZ+^_QJ1,-WE10!3XY_^_QH`,.#C.2#@XR0`G>4`
M0(WE8?;_ZXP0C>(D`)WE*2"@XQ7V_^N,D(WB3,"?Y04`H.$!$*#C`"#@XV`P
MG^7`$HWHB_;_ZV7^_^I9]O_K#,\``,"R`0"<SP``*'___\3/``#$T```N-``
M`.T!```8T@``S-```*S0```,T```R-```/30```$T0``7'___P$C16?^W+J8
M=E0R$/#ATL/LT```W-```$!____4T```4'___[#0``#P3RWI;*2?Y0':3>(,
MT$WB`#":Y0$JC>($,(+E``"@XW7V_^L``)#EZ?7_Z^[U_^L!,*#C`##`Y3P$
MG^4N^O_K``!0XP(```H`,-#E,0!3XY````K*_/_K``"@XV;V_^L``)#EVO7_
MZQ`4G^4!(*#C"S"@X[7U_^L``%#C`&2?!30```KX8Y_E#""0Y?0_%N48@)+E
M`0!3XP!0H-,J``#:`%"@XP%`H.,(``#J!P"@X6#V_^L``%#C(@``&O0_%N4!
M0(3B!`!3X0%0A>(>``#:``"@XTCV_^L``)#EO/7_ZP@0H.$%(*#A`#"@X^7U
M_^L`L%#B$P``"@`PF^7P+Q;E")"3Y01QDN<!FQGB#!"3%>7__QH)`*#A-_;_
MZP``D.6K]?_K`!";Y0D@H.$",*#C3/;_ZP`0H.$'`*#A/?;_ZP``4./<__\*
M]#\6Y0$@0^(%`%+A4P``"@``H.,F]O_K``"0Y9KU_^L8$Y_E`2"@XP0PH.-U
M]?_K`$!0X@P```H``*#C'/;_ZP``D.60]?_K##"4Y?`BG^4`$)/E<?7_ZPPP
ME.4`,)/E"#"3Y0$%$^-*```:``"@XP_V_^L``)#E@_7_Z\02G^4!(*#C!#"@
MXU[U_^L`0%#B"P``"K`"G^7%^?_K`%!0XD0```H``*#C`?;_ZP``D.5U]?_K
M##"4Y04@H.$`$)/E5O7_ZP``H./Y]?_K`'"@XV12G^4``)#E:_7_ZW#U_^L`
M<,#E!P"@X?'U_^L``)#E9?7_Z_KU_^L`<(#E3`*?Y:OY_^L'`%#A[`\&Y5P`
M``H\$I_E$?7_ZQ$`4.,``%`3`#"@X0$```H!`'#C3P``&@$ZC>($()/E`#":
MY0,`4N%)```:#-"-X@':C>+PC[WH`3#0Y0``4^-L__\*:O__Z@$`4^.I___:
M`4"@XP``H.//]?_K`4"$X@``D.5"]?_K"!"@X1SU_^OT/Q;E!`!3X?7__\J=
M___J``"@X\3U_^L``)#E./7_ZPPPE.4`$)/E=_7_ZZS__^J]]?_K"%"-X@10
M1>(``)#E+_7_ZPS`E.7P/Q;E?`&?Y040H.%X(9_E`("<Y0"0D^63]?_K`'!0
MXA4``-H!,$?B`R#5YP``4N,"```:``!3XP\```H#<*#A!0"@X2\0H.,'(*#A
MK?7_ZP``4.,(```*``"@XZ#U_^L``)#E%/7_ZP@0H.$%(*#A!S"@X3?U_^N=
M___J``"@XY?U_^L``)#E"_7_ZP@0H.$)(*#A[?3_ZY7__^I1]?_K\"\5Y>0`
MG^4`$)+E["\5Y6'U_^OP#Q7EK?S_ZPPPE.4`,)/E"'"3Y0%[%^+L#P7E#`"3
M%0@``!H'`*#A@/7_ZP``D.7T]/_K##"4Y0<@H.$`$)/E`C"@XY3U_^OP'Q;E
MU?3_ZPPPE.7P+Q;E`#"3Y0!@DN4(<)/E`7L7X@P@DQ4`4*#A"0``&@<`H.%L
M]?_K``"0Y>#T_^L,,)3E!R"@X0`0D^4",*#C@/7_ZP`@H.$\`)_E!A"@X04P
MH.$V]?_KP+(!`/#/```8T0``U-(!`"#1```DT0``+-$``*C/``"<SP``[0$`
M`##1``#_#P``<-$``$#1``!P0"WI`%"@X67[_^L`,-#E``!3XP!`H`$&```*
M`2"`X@!`H.$O`%/C`D"@`0$PTN0``%/C^O__&A#\_^L``%#C<("]"```5>-P
M@+T(`##5Y0``4^-P@+T(!`"@X100G^7?]/_K``!4X7"`O1@%`*#A<$"]Z('Y
M_^K$T```$$`MZ0``H.,P]?_K``"0Y:3T_^L`$.#CF?3_ZP``H.,J]?_K``"0
MY9[T_^L`(*#C!!"?Y1!`O>@\]?_J_*H``'!`+>D8T$WB%`"-Y1`0C>4,((WE
M%`"-XA`0C>(,((WB%_7_Z_01G^7T`9_E`2"@X8<``.L``*#C>_3_ZP!`T.4`
M`%3C"P``&G3T_^O4(9_E``!0X^@/`N5N```*F?3_ZP0`H.$)]?_K``"0Y7WT
M_^O?]/_K`$#`Y0``H.,#]?_K``"0Y7?T_^L&]?_K`"#0Y0`PH.$"((+C`"##
MY0``H./Z]/_K``"0Y6[T_^O]]/_K`##0Y0$P@^,`,,#E%$"=Y05`A.($`*#A
M-0$`ZP`@H.,`,*#CAP``ZTPAG^5,,9_EM0$`ZP``4.-'```:!`&@X<7T_^LL
M09_E$!"=Y110G>4!`%7C\`\$Y0`PD>4`,(#E'#&?Y00P@.48,9_E"#"`Y10Q
MG^4,,(#E!#"@XP#`H.$,((#B]#\$Y04``-H!,*#C`3"#X@0`L>4%`%/A!`"B
MY?K__QH#4(7BZ`\4Y0#@H.,%(*#AU!"?Y0PPH.$%X8SG`."-Y?SS_^L`4%#B
M#```"N@/%.5M]/_KM`"?Y7_X_^N08)_E``!0XQ````KH#Q3EZ//_ZSOT_^L%
M`*#A&-"-XG"`O>AL,)_E:&"?Y>@/$^4!]/_K`%"@X>@/%.5;]/_K;`"?Y6WX
M_^L``%#C[O__&NP/%N4``%#C`0``"E3__^OI___J3`"?Y63X_^L``%#C[`\&
MY>3__PKW___J.`"?Y3@0G^5S]/_K`0"@XZWT_^MTF```H)D``-32`0```(#_
M___/0<#1```TT@``Q-$``(2P````T```G,\``.C0``#(L@$`'#"?Y1S`G^4$
M0"WE`S"/X`Q`D^`,,),7!#"@`1``O>A8]/_J].<``(`=___X12WI4%"?Y5"@
MG^4`8*#A`7"@X0*`H.&<\__K0#"?Y0J@9>`#,(_@2J&PX050@^#XA;T(`$"@
MXP0PE>0&`*#A!Q"@X0@@H.$!0(3B,_\OX0H`5.'W__\Z^(6]Z+3^__^X_O__
ML.<``![_+^$"$2'B````Z@(Q(^(P0"WI@4"@X8-0H.$%`#3A`@`P`0#`E!$"
MP)41Q,KP$<7*\!%Y```*I$J@X:5:=.``4&6R!@``V@5`A.`"("#@`S`AX```
M(N`!$"/@`B`@X`,P(>`V`%7C,("]B`(!$>,!%J#A`<:@XR$6C.$!```*``!P
MX@`0X>("`1/C`S:@X2,VC.$!```*`"!RX@`PX^(%`#3A5P``"@%`1.(@X'7B
M!0``NA+.H.$R!9#@`!"AXA,.D.!3%;'@!@``ZB!01>(@X([B`0!2XQ/.H.$"
MP(PC4P60X,,?L>`"40'B`@``6@#`?.(``/#B`!#AX@$&4>,.```Z`@91XP8`
M`#JA$+#A8`"PX6S`H.$!0(3BA"J@X0$%<N-5```J`@%<XZ#`L`$``+#B!!JA
MX`40@>$P@+WHC,"PX0``L.`!$*'@`081XP%`1.+S__\:```QXP`0H`$``*`#
M$3]OX2`P@P(+,$/B("!3X@<``*H,()+B!```VA3`@N(,(&+B$0R@X3$2H.$$
M``#J%"""XB#`8M(1$J#A,!R!T1`"H-$#0%3@!!J!H`40@:$P@+VH!$#@X1]`
M5.(-``"J#$"4X@4``,H40(3B("!DXC`$H.$1`H#A,12%X3"`O>@,0&3B("!D
MXC`"H.$1!(#A!1"@X3"`O>@Q!*#A!1"@X3"`O>@``#3C`38CX@$6(0(!0(0"
M`5!%$J'__^K$RO#AQ<KP$1@```H%`#3A`@`P`0,```H`P)3A`Q"@`0(`H`$P
M@+WH`P`QX0`0H!,``*`3,("]&*3*L.$#```:@`"PX0$0L>`"$8$C,("]Z`%%
ME.(!%H$R,("].`)1`>)_%(7C#Q:!XP``H.,P@+WHQ,KPX0,0H!$"`*`1Q<KP
M`0$PH!$`(*`1`4:0X0-6D@$#`#$!`A>!$S"`O>@``##C`!"@`Q[_+P$P0"WI
M`4N@XS)`A.(`4*#C`!"@XYW__^H``##C`!"@`Q[_+P$P0"WI`4N@XS)`A.("
M41#B``!@0@`0H..3___J@""PX<(1H.%A$*#A`@Z@X?\T$A+_!#,3#A,A$A[_
M+Q$``#+C_P0S$Q[_+P$P0"WI#DV@XP)1`>("$<'C@___Z@$@D.$>_R\!,$`M
MZ0!0H.,&``#J`2"0X1[_+P$P0"WI`E$1X@$``%H``'#B`!#AX@%+H.,R0(3B
M(<NPX5S__PH#(*#CK,&PX0,@@A*LP;#A`R""$JPA@N`@,&+B$,.@X3`"H.$1
M`X#A,1*@X0)`A.!/___J`,#@XP(``.H!P*#C````Z@'`H.,$P"WE@<"@X<S*
M\.&#P*#AS,KP$0X```H$T(WB@<"0X8/`D@$#`#$1`@`P`0``H`,>_R\!``!P
MXP,`,>$#`%%1`@!0`<,/H"'##^`Q`0"`XQ[_+^&!P*#AS,KPX0$``!H!QI#A
M!```&H/`H.',RO#AZ/__&@/&DN'F__\*!`"=Y![_+^$`P*#A`@"@X0P@H.$!
MP*#A`Q"@X0PPH.'____J`4`MZ=3__^L``%#C``!P0P&`O>@(X"WE^/__ZP$`
MH`,``*`3"/"=Y`C@+>7S___K`0"@,P``H",(\)WD".`MY>[__^L!`*"3``"@
M@PCPG>0(X"WEXO__ZP$`H),``*"#"/"=Y`C@+>7=___K`0"@,P``H",(\)WD
M"$`MZ0B`O>@!``(``````%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@
M("`@`````/C1```(T@``$-(``!C2```@T@``R-```.C1``#PT0``F,\``,C0
M``!PT```=-```-S1``"@SP``Y-$``,C0``#(T0``T-$``,C0```E<R\E<P``
M`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!P97)L>'-I+F,```!);G1E
M<FYA;',Z.E!!4CHZ0D]/5``````O<')O8R\E:2\E<P!E>&4`+@```%!!4E]4
M14U0`````%!!4E]04D]'3D%-10`````Z````)7,E<R5S```O````4$523#5,
M24(`````4$523$Q)0@!015),-4]05`````!015),24\``%!!4E])3DE424%,
M25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X```!005)?1$5"54<```!005)?
M0T%#2$4```!005)?05)'0P````!005)?05)'5E\P``!005)?1TQ/0D%,7T1%
M0E5'`````%!!4E]'3$]"04Q?5$U01$E2````4$%27U1-4$1)4@``4$%27T=,
M3T)!3%]414U0`%!!4E]'3$]"04Q?0TQ%04X`````4$%27T-,14%./0``,0``
M`%-94U1%30``)7,E<R5S)7,`````<&%R+0````!P87)L`````"YP87(`````
M)7,E<V-A8VAE+25S)7,``"4P,G@`````)7,E<W1E;7`M)74E<P```"5S)7-T
M96UP+25U+25U)7,`````05)'5@`````8````<&5R;``````P````+W!R;V,O
M<V5L9B]E>&4``"5S.B!E>&5C=71I;VX@;V8@)7,@9F%I;&5D("T@86)O<G1I
M;F<@=VET:"`E:2X*`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('1E;7!O<F%R
M>2!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("T@86)O<G1I;F<@=VET:"`E:2X*
M````+64``"TM``!54T52`````%5315).04U%`````%1%35!$25(`5$U0`$,Z
M7%1%35``+W1M<`````!,1%],24)205)97U!!5$@`3$E"4$%42`!,24)205)9
M7U!!5$@`````1%E,1%],24)205)97U!!5$@````C(2]U<W(O8FEN+W!E<FP*
M979A;"`G97AE8R`O=7-R+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"B`@
M("!I9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*"G!A8VMA
M9V4@7U]P87)?<&P["@HC("TM+2!4:&ES('-C<FEP="!M=7-T(&YO="!U<V4@
M86YY(&UO9'5L97,@870@8V]M<&EL92!T:6UE("TM+0HC('5S92!S=')I8W0[
M"@HC;&EN92`Q-3@*"FUY("@D<&%R7W1E;7`L("1P<F]G;F%M92P@0'1M<&9I
M;&4I.PI%3D0@>R!I9B`H)$5.5GM005)?0TQ%04Y]*2!["B`@("!R97%U:7)E
M($9I;&4Z.E1E;7`["B`@("!R97%U:7)E($9I;&4Z.D)A<V5N86UE.PH@("`@
M<F5Q=6ER92!&:6QE.CI3<&5C.PH@("`@;7D@)'1O<&1I<B`]($9I;&4Z.D)A
M<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["B`@("!O=71S*'%Q>U)E;6]V
M:6YG(&9I;&5S(&EN("(D<&%R7W1E;7`B?2D["B`@("!&:6QE.CI&:6YD.CIF
M:6YD9&5P=&@H<W5B('L@*"`M9"`I(#\@<FUD:7(@.B!U;FQI;FL@?2P@)'!A
M<E]T96UP*3L*("`@(')M9&ER("1P87)?=&5M<#L*("`@(",@1&]N)W0@<F5M
M;W9E('1O<&1I<B!B96-A=7-E('1H:7,@8V%U<V5S(&$@<F%C92!W:71H(&]T
M:&5R(&%P<',*("`@(",@=&AA="!A<F4@=')Y:6YG('1O('-T87)T+@H*("`@
M(&EF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I;C,R)RD@>PH@("`@
M("`@(",@4V]M971H:6YG('=E;G0@=W)O;F<@=6YL:6YK:6YG('1H92!T96UP
M;W)A<GD@9&ER96-T;W)Y+B`@5&AI<PH@("`@("`@(",@='EP:6-A;&QY(&AA
M<'!E;G,@;VX@<&QA=&9O<FUS('1H870@9&ES86QL;W<@=6YL:6YK:6YG('-H
M87)E9`H@("`@("`@(",@;&EB<F%R:65S(&%N9"!E>&5C=71A8FQE<R!T:&%T
M(&%R92!I;B!U<V4N(%5N;&EN:R!W:71H(&$@8F%C:V=R;W5N9`H@("`@("`@
M(",@<VAE;&P@8V]M;6%N9"!S;R!T:&4@9FEL97,@87)E(&YO(&QO;F=E<B!I
M;B!U<V4@8GD@=&AI<R!P<F]C97-S+@H@("`@("`@(",@1&]N)W0@9&\@86YY
M=&AI;F<@;VX@5VEN9&]W<R!B96-A=7-E(&]U<B!P87)E;G0@<')O8V5S<R!W
M:6QL"B`@("`@("`@(R!T86ME(&-A<F4@;V8@8VQE86YI;F<@=&AI;F=S('5P
M+@H*("`@("`@("!M>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"B`@("`@("`@
M("`@(%1%35!,051%(#T^("=T;7!86%A86"<L"B`@("`@("`@("`@($1)4B`]
M/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D=&]P9&ER*2P*("`@("`@("`@
M("`@4U5&1DE8(#T^("<N8VUD)RP*("`@("`@("`@("`@54Y,24Y+(#T^(#`L
M"B`@("`@("`@*3L*"B`@("`@("`@<')I;G0@)'1M<"`B(R$O8FEN+W-H"G@]
M,3L@=VAI;&4@6R!<)'@@+6QT(#$P(%T[(&1O"B`@(')M("UR9B`G)'!A<E]T
M96UP)PH@("!I9B!;(%PA("UD("<D<&%R7W1E;7`G(%T[('1H96X*("`@("`@
M(&)R96%K"B`@(&9I"B`@('-L965P(#$*("`@>#U@97AP<B!<)'@@*R`Q8`ID
M;VYE"G)M("<B("X@)'1M<"T^9FEL96YA;64@+B`B)PHB.PH@("`@("`@("`@
M("!C:&UO9"`P-S`P+"1T;7`M/F9I;&5N86UE.PH@("`@("`@(&UY("1C;60@
M/2`D=&UP+3YF:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G.PH@("`@
M("`@(&-L;W-E("1T;7`["B`@("`@("`@<WES=&5M*"1C;60I.PH@("`@("`@
M(&]U=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R;V-E<W,@=&\@<&5R9F]R
M;2!C;&5A;G5P.B`I"B`@("`@("`@("`@("`N("1T;7`M/F9I;&5N86UE*3L*
M("`@('T*?2!]"@I"14=)3B!["B`@("!);G1E<FYA;',Z.E!!4CHZ0D]/5"@I
M(&EF(&1E9FEN960@)DEN=&5R;F%L<SHZ4$%2.CI"3T]4.PH*("`@(&5V86P@
M>PH*7W!A<E]I;FET7V5N=B@I.PH*:68@*&5X:7-T<R`D14Y6>U!!4E]!4D=6
M7S!](&%N9"`D14Y6>U!!4E]!4D=67S!]("D@>PH@("`@0$%21U8@/2!M87`@
M)$5.5GLB4$%27T%21U9?)%\B?2P@*#$@+BX@)$5.5GM005)?05)'0WT@+2`Q
M*3L*("`@("0P(#T@)$5.5GM005)?05)'5E\P?3L*?0IE;'-E('L*("`@(&9O
M<B`H:V5Y<R`E14Y6*2!["B`@("`@("`@9&5L971E("1%3E9[)%]](&EF("]>
M4$%27T%21U9?+SL*("`@('T*?0H*;7D@)'%U:65T(#T@(21%3E9[4$%27T1%
M0E5'?3L*"B,@9FEX("1P<F]G;F%M92!I9B!I;G9O:V5D(&9R;VT@4$%42`IM
M>2`E0V]N9FEG(#T@*`H@("`@<&%T:%]S97`@("`@/3X@*"1>3R`]?B`O7DU3
M5VEN+R`_("<[)R`Z("<Z)RDL"B`@("!?97AE("`@("`@("`]/B`H)%Y/(#U^
M("]>*#\Z35-7:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`H@("`@
M7V1E;&EM("`@("`@/3X@*"1>3R`]?B`O7DU35VEN?$]3,B\@/R`G7%PG(#H@
M)R\G*2P**3L*"E]S971?<')O9VYA;64H*3L*7W-E=%]P87)?=&5M<"@I.PH*
M(R!-86=I8R!S=')I;F<@8VAE8VMI;F<@86YD(&5X=')A8W1I;F<@8G5N9&QE
M9"!M;V1U;&5S('M[>PIM>2`H)'-T87)T7W!O<RP@)&1A=&%?<&]S*3L*>PH@
M("`@;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["@H@("`@(R!#:&5C
M:R!F:6QE('1Y<&4L(&=E="!S=&%R="!O9B!D871A('-E8W1I;VX@>WM["B`@
M("!O<&5N(%]&2"P@)SPG+"`D<')O9VYA;64@;W(@;&%S=#L*("`@(&)I;FUO
M9&4H7T9(*3L*"B`@("!M>2`D8G5F.PH@("`@<V5E:R!?1D@L("TX+"`R.PH@
M("`@<F5A9"!?1D@L("1B=68L(#@["B`@("!L87-T('5N;&5S<R`D8G5F(&5Q
M(")<;E!!4BYP;5QN(CL*"B`@("!S965K(%]&2"P@+3$R+"`R.PH@("`@<F5A
M9"!?1D@L("1B=68L(#0["B`@("!S965K(%]&2"P@+3$R("T@=6YP86-K*").
M(BP@)&)U9BDL(#(["B`@("!R96%D(%]&2"P@)&)U9BP@-#L*"B`@("`D9&%T
M85]P;W,@/2`H=&5L;"!?1D@I("T@-#L*("`@(",@?7U]"@H@("`@(R!%>'1R
M86-T:6YG(&5A8V@@9FEL92!I;G1O(&UE;6]R>2![>WL*("`@(&UY("5R97%U
M:7)E7VQI<W0["B`@("!W:&EL92`H)&)U9B!E<2`B1DE,12(I('L*("`@("`@
M("!R96%D(%]&2"P@)&)U9BP@-#L*("`@("`@("!R96%D(%]&2"P@)&)U9BP@
M=6YP86-K*").(BP@)&)U9BD["@H@("`@("`@(&UY("1F=6QL;F%M92`]("1B
M=68["B`@("`@("`@;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE
M(BXN+BDI.PH@("`@("`@(&UY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH
M6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["B`@("`@("`@;7D@*"1B
M87-E;F%M92P@)&5X="D@/2`H)&)U9B`]?B!M?"@_.BXJ+RD_*"XJ*2A<+BXJ
M*7PI.PH*("`@("`@("!R96%D(%]&2"P@)&)U9BP@-#L*("`@("`@("!R96%D
M(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["@H@("`@("`@(&EF("AD
M969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L*20O
M:2D@>PH@("`@("`@("`@("!M>2`H)&]U="P@)&9I;&5N86UE*2`](%]T96UP
M9FEL92@D97AT+"`D8W)C*3L*("`@("`@("`@("`@:68@*"1O=70I('L*("`@
M("`@("`@("`@("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@("`@("`@("!P
M<FEN="`D;W5T("1B=68["B`@("`@("`@("`@("`@("!C;&]S92`D;W5T.PH@
M("`@("`@("`@("`@("`@8VAM;V0@,#<U-2P@)&9I;&5N86UE.PH@("`@("`@
M("`@("!]"B`@("`@("`@("`@("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U
M;&QN86UE?2`]("1F:6QE;F%M93L*("`@("`@("`@("`@)%!!4CHZ2&5A=GDZ
M.D9U;&Q#86-H97LD9FEL96YA;65](#T@)&9U;&QN86UE.PH@("`@("`@('T*
M("`@("`@("!E;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB+WP@86YD
M(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["B`@("`@("`@("`@(",@<VAO
M=6QD(&)E(&UO=F5D('1O(%]T96UP9FEL92@I"B`@("`@("`@("`@(&UY("1F
M:6QE;F%M92`]("(D14Y6>U!!4E]414U0?2\D8F%S96YA;64D97AT(CL*("`@
M("`@("`@("`@;W5T<R@B4TA,24(Z("1F:6QE;F%M95QN(BD["B`@("`@("`@
M("`@(&]P96X@;7D@)&]U="P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PH@
M("`@("`@("`@("!B:6YM;V1E*"1O=70I.PH@("`@("`@("`@("!P<FEN="`D
M;W5T("1B=68["B`@("`@("`@("`@(&-L;W-E("1O=70["B`@("`@("`@?0H@
M("`@("`@(&5L<V4@>PH@("`@("`@("`@("`D<F5Q=6ER95]L:7-T>R1F=6QL
M;F%M97T@/0H@("`@("`@("`@("`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[
M)&9U;&QN86UE?2`]('L*("`@("`@("`@("`@("`@(&)U9B`]/B`D8G5F+`H@
M("`@("`@("`@("`@("`@8W)C(#T^("1C<F,L"B`@("`@("`@("`@("`@("!N
M86UE(#T^("1F=6QL;F%M92P*("`@("`@("`@("`@?3L*("`@("`@("!]"B`@
M("`@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("!]"B`@("`C('U]?0H*("`@
M(&QO8V%L($!)3D,@/2`H<W5B('L*("`@("`@("!M>2`H)'-E;&8L("1M;V1U
M;&4I(#T@0%\["@H@("`@("`@(')E='5R;B!I9B!R968@)&UO9'5L92!O<B`A
M)&UO9'5L93L*"B`@("`@("`@;7D@)&9I;&5N86UE(#T@9&5L971E("1R97%U
M:7)E7VQI<W1[)&UO9'5L97T@?'P@9&\@>PH@("`@("`@("`@("!M>2`D:V5Y
M.PH@("`@("`@("`@("!F;W)E86-H("AK97ES("5R97%U:7)E7VQI<W0I('L*
M("`@("`@("`@("`@("`@(&YE>'0@=6YL97-S("]<421M;V1U;&5<120O.PH@
M("`@("`@("`@("`@("`@)&ME>2`]("1?.R!L87-T.PH@("`@("`@("`@("!]
M"B`@("`@("`@("`@(&1E;&5T92`D<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E
M9FEN960H)&ME>2D["B`@("`@("`@?2!O<B!R971U<FX["@H@("`@("`@("1)
M3D-[)&UO9'5L97T@/2`B+VQO861E<B\D9FEL96YA;64O)&UO9'5L92(["@H@
M("`@("`@(&EF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/.CI&
M:6QE.CIN97<I*2!["B`@("`@("`@("`@(&UY("1F:"`]($E/.CI&:6QE+3YN
M97=?=&UP9FEL92!O<B!D:64@)"$["B`@("`@("`@("`@(&)I;FUO9&4H)&9H
M*3L*("`@("`@("`@("`@<')I;G0@)&9H("1F:6QE;F%M92T^>V)U9GT["B`@
M("`@("`@("`@('-E96LH)&9H+"`P+"`P*3L*("`@("`@("`@("`@<F5T=7)N
M("1F:#L*("`@("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@(&UY
M("@D;W5T+"`D;F%M92D@/2!?=&5M<&9I;&4H)RYP;2<L("1F:6QE;F%M92T^
M>V-R8WTI.PH@("`@("`@("`@("!I9B`H)&]U="D@>PH@("`@("`@("`@("`@
M("`@8FEN;6]D92@D;W5T*3L*("`@("`@("`@("`@("`@('!R:6YT("1O=70@
M)&9I;&5N86UE+3Y[8G5F?3L*("`@("`@("`@("`@("`@(&-L;W-E("1O=70[
M"B`@("`@("`@("`@('T*("`@("`@("`@("`@;W!E;B!M>2`D9F@L("<\)RP@
M)&YA;64@;W(@9&EE("0A.PH@("`@("`@("`@("!B:6YM;V1E*"1F:"D["B`@
M("`@("`@("`@(')E='5R;B`D9F@["B`@("`@("`@?0H*("`@("`@("!D:64@
M(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C86YN;W0@9FEN9"`D;6]D=6QE(5QN
M(CL*("`@('TL($!)3D,I.PH*("`@(",@3F]W(&QO860@86QL(&)U;F1L960@
M9FEL97,@>WM["@H@("`@(R!I;FET:6%L:7IE('-H87)E9"!O8FIE8W0@<')O
M8V5S<VEN9PH@("`@<F5Q=6ER92!84TQO861E<CL*("`@(')E<75I<F4@4$%2
M.CI(96%V>3L*("`@(')E<75I<F4@0V%R<#HZ2&5A=GD["B`@("!R97%U:7)E
M($5X<&]R=&5R.CI(96%V>3L*("`@(%!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L
M;V%D97(H*3L*"B`@("`C(&YO=R!L970G<R!T<GD@9V5T=&EN9R!H96QP97(@
M;6]D=6QE<R!F<F]M('=I=&AI;@H@("`@<F5Q=6ER92!)3SHZ1FEL93L*"B`@
M("`C(&QO860@<F5S="!O9B!T:&4@9W)O=7`@:6X*("`@('=H:6QE("AM>2`D
M9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2!["B`@
M("`@("`@(VQO8V%L("1)3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/
M(&YE("=-4U=I;C,R)SL*("`@("`@("!U;FQE<W,@*"1)3D-[)&9I;&5N86UE
M?2!O<B`D9FEL96YA;64@/7X@+T)31%!!3B\I('L*("`@("`@("`@("`@(R!R
M97%U:7)E(&UO9'5L97,L(&1O(&]T:&5R(&5X96-U=&%B;&4@9FEL97,*("`@
M("`@("`@("`@:68@*"1F:6QE;F%M92`]?B`O7"YP;6,_)"]I*2!["B`@("`@
M("`@("`@("`@("!R97%U:7)E("1F:6QE;F%M93L*("`@("`@("`@("`@?0H@
M("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@(",@4VMI<"!!8W1I
M=F53=&%T92=S('-I=&5C=7-T;VUI>F4N<&P@9FEL93H*("`@("`@("`@("`@
M("`@(&1O("1F:6QE;F%M92!U;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S
M=&]M:7IE7"YP;"0O.PH@("`@("`@("`@("!]"B`@("`@("`@?0H@("`@("`@
M(&1E;&5T92`D<F5Q=6ER95]L:7-T>R1F:6QE;F%M97T["B`@("!]"@H@("`@
M(R!]?7T*"B`@("!L87-T('5N;&5S<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*
M("`@("1S=&%R=%]P;W,@/2`H=&5L;"!?1D@I("T@-#L*?0HC('U]?0H*(R!!
M<F=U;65N="!P<F]C97-S:6YG('M[>PIM>2!`<&%R7V%R9W,["FUY("@D;W5T
M+"`D8G5N9&QE+"`D;&]G9F@L("1C86-H95]N86UE*3L*"F1E;&5T92`D14Y6
M>U!!4E]!4%!?4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S
M96-U<FET>2!P<F]B;&5M*0H*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?
M1$5"54=].PHC($1O;B=T('-W86QL;W<@87)G=6UE;G1S(&9O<B!C;VUP:6QE
M9"!E>&5C=71A8FQE<R!W:71H;W5T("TM<&%R+6]P=&EO;G,*:68@*"$D<W1A
M<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M;W!T:6]N<R<@)B8@<VAI
M9G0I*2!["B`@("!M>2`E9&ES=%]C;60@/2!Q=R@*("`@("`@("!P("`@8FQI
M8E]T;U]P87(*("`@("`@("!I("`@:6YS=&%L;%]P87(*("`@("`@("!U("`@
M=6YI;G-T86QL7W!A<@H@("`@("`@(',@("!S:6=N7W!A<@H@("`@("`@('8@
M("!V97)I9GE?<&%R"B`@("`I.PH*("`@(",@:68@=&AE(&%P<"!I<R!I;G9O
M:V5D(&%S(")A<'!N86UE("TM<&%R+6]P=&EO;G,@+2UR975S92!04D]'4D%-
M($!04D]'7T%21U8B+`H@("`@(R!U<V4@=&AE(&%P<"!T;R!R=6X@=&AE(&=I
M=F5N('!E<FP@8V]D92!I;G-T96%D(&]F(&%N>71H:6YG(&9R;VT@=&AE"B`@
M("`C(&%P<"!I='-E;&8@*&)U="!S=&EL;"!S970@=7`@=&AE(&YO<FUA;"!A
M<'`@96YV:7)O;FUE;G0@86YD($!)3D,I"B`@("!I9B`H0$%21U8@86YD("1!
M4D=66S!=(&5Q("<M+7)E=7-E)RD@>PH@("`@("`@('-H:69T($!!4D=6.PH@
M("`@("`@("1%3E9[4$%27T%04%]2155317T@/2!S:&EF="!`05)'5CL*("`@
M('T*("`@(&5L<V4@>R`C(&YO<FUA;"!P87)L(&)E:&%V:6]U<@H*("`@("`@
M("!M>2!`861D7W1O7VEN8SL*("`@("`@("!W:&EL92`H0$%21U8I('L*("`@
M("`@("`@("`@)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ
M*2\@;W(@;&%S=#L*"B`@("`@("`@("`@(&EF("@D,2!E<2`G22<I('L*("`@
M("`@("`@("`@("`@('!U<V@@0&%D9%]T;U]I;F,L("0R.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G32<I('L*("`@("`@("`@
M("`@("`@(&5V86P@(G5S92`D,B(["B`@("`@("`@("`@('T*("`@("`@("`@
M("`@96QS:68@*"0Q(&5Q("=!)RD@>PH@("`@("`@("`@("`@("`@=6YS:&EF
M="!`<&%R7V%R9W,L("0R.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L
M<VEF("@D,2!E<2`G3R<I('L*("`@("`@("`@("`@("`@("1O=70@/2`D,CL*
M("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)V(G*2![
M"B`@("`@("`@("`@("`@("`D8G5N9&QE(#T@)W-I=&4G.PH@("`@("`@("`@
M("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G0B<I('L*("`@("`@("`@
M("`@("`@("1B=6YD;&4@/2`G86QL)SL*("`@("`@("`@("`@?0H@("`@("`@
M("`@("!E;'-I9B`H)#$@97$@)W$G*2!["B`@("`@("`@("`@("`@("`D<75I
M970@/2`Q.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E
M<2`G3"<I('L*("`@("`@("`@("`@("`@(&]P96X@)&QO9V9H+"`B/CXB+"`D
M,B!O<B!D:64@(EA86#H@0V%N;F]T(&]P96X@;&]G.B`D(2(["B`@("`@("`@
M("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=4)RD@>PH@("`@("`@
M("`@("`@("`@)&-A8VAE7VYA;64@/2`D,CL*("`@("`@("`@("`@?0H*("`@
M("`@("`@("`@<VAI9G0H0$%21U8I.PH*("`@("`@("`@("`@:68@*&UY("1C
M;60@/2`D9&ES=%]C;61[)#%]*2!["B`@("`@("`@("`@("`@("!D96QE=&4@
M)$5.5GLG4$%27U1%35`G?3L*("`@("`@("`@("`@("`@(&EN:71?:6YC*"D[
M"B`@("`@("`@("`@("`@("!R97%U:7)E(%!!4CHZ1&ES=#L*("`@("`@("`@
M("`@("`@("9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PH@
M("`@("`@("`@("`@("`@)GLB4$%2.CI$:7-T.CHD8VUD(GTH)%\I(&9O<B!`
M05)'5CL*("`@("`@("`@("`@("`@(&5X:70["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@('5N<VAI9G0@0$E.0RP@0&%D9%]T;U]I;F,["B`@
M("!]"GT*"B,@6%A8("TM(&%D9"`M+7!A<BUD96)U9R!S=7!P;W)T(0H*(R!]
M?7T*"B,@3W5T<'5T(&UO9&4@*"U/*2!H86YD;&EN9R![>WL*:68@*"1O=70I
M('L*("`@('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D+G!M)WT@/2!?7T9)
M3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@(')E<75I<F4@24\Z
M.D9I;&4["B`@("`@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!]"@H@
M("`@;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*("`@(&UY("1Z:7`["@H*("`@
M(&EF("AD969I;F5D("1P87(I('L*("`@("`@("!O<&5N(&UY("1F:"P@)SPG
M+"`D<&%R(&]R(&1I92`B0V%N;F]T(&9I;F0@)R1P87(G.B`D(2(["B`@("`@
M("`@8FEN;6]D92@D9F@I.PH@("`@("`@(&)L97-S*"1F:"P@)TE/.CI&:6QE
M)RD["@H@("`@("`@("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*("`@("`@
M("`H("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P87(I(#T]($%R
M8VAI=F4Z.EII<#HZ05I?3TLH*2`I"B`@("`@("`@("`@(&]R(&1I92`B4F5A
M9"`G)'!A<B<@97)R;W(Z("0A(CL*("`@('T*"@H@("`@;7D@)65N=B`](&1O
M('L*("`@("`@("!I9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT
M96YT<R@G345402YY;6PG*2D@>PH@("`@("`@("`@("`D;65T82`]?B!S+RXJ
M7G!A<CHD+R]M<SL*("`@("`@("`@("`@)&UE=&$@/7X@<R]>7%,N*B\O;7,[
M"B`@("`@("`@("`@("1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI)"]M9SL*
M("`@("`@("!]"B`@("!].PH*("`@(",@3W!E;B!I;G!U="!A;F0@;W5T<'5T
M(&9I;&5S('M[>PH@("`@;&]C86P@)"\@/2!<-#L*"B`@("!I9B`H9&5F:6YE
M9"`D<&%R*2!["B`@("`@("`@;W!E;B!005(L("<\)RP@)'!A<B!O<B!D:64@
M(B0A.B`D<&%R(CL*("`@("`@("!B:6YM;V1E*%!!4BD["B`@("`@("`@9&EE
M("(D<&%R(&ES(&YO="!A(%!!4B!F:6QE(B!U;FQE<W,@/%!!4CX@97$@(E!+
M7#`P,UPP,#0B.PH@("`@?0H*("`@($-R96%T95!A=&@H)&]U="D@.PH@("`@
M"B`@("!M>2`D9F@@/2!)3SHZ1FEL92T^;F5W*`H@("`@("`@("1O=70L"B`@
M("`@("`@24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,
M62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*("`@("`@("`P-S<W+`H@("`@
M*2!O<B!D:64@)"$["B`@("!B:6YM;V1E*"1F:"D["@H@("`@)"\@/2`H9&5F
M:6YE9"`D9&%T85]P;W,I(#\@7"1D871A7W!O<R`Z('5N9&5F.PH@("`@<V5E
M:R!?1D@L(#`L(#`["B`@("!M>2`D;&]A9&5R(#T@<V-A;&%R(#Q?1D@^.PH@
M("`@:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH
M/SHC(7Q<0')E;2DO*2!["B`@("`@("`@<F5Q=6ER92!005(Z.D9I;'1E<CHZ
M4&]D4W1R:7`["B`@("`@("`@4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M
M/F%P<&QY*%PD;&]A9&5R+"`D,"D*("`@('T*("`@(&9O<F5A8V@@;7D@)&ME
M>2`H<V]R="!K97ES("5E;G8I('L*("`@("`@("!M>2`D=F%L(#T@)&5N=GLD
M:V5Y?2!O<B!N97AT.PH@("`@("`@("1V86P@/2!E=F%L("1V86P@:68@)'9A
M;"`]?B`O7ELG(ETO.PH@("`@("`@(&UY("1M86=I8R`](")?7T5.5E]005)?
M(B`N('5C*"1K97DI("X@(E]?(CL*("`@("`@("!M>2`D<V5T(#T@(E!!4E\B
M("X@=6,H)&ME>2D@+B`B/21V86PB.PH@("`@("`@("1L;V%D97(@/7X@<WLD
M;6%G:6,H("LI?7L*("`@("`@("`@("`@)&UA9VEC("X@)'-E="`N("@G("<@
M>"`H;&5N9W1H*"0Q*2`M(&QE;F=T:"@D<V5T*2DI"B`@("`@("`@?65G.PH@
M("`@?0H@("`@)&9H+3YP<FEN="@D;&]A9&5R*3L*("`@("0O(#T@=6YD968[
M"B`@("`C('U]?0H*("`@(",@5W)I=&4@8G5N9&QE9"!M;V1U;&5S('M[>PH@
M("`@:68@*"1B=6YD;&4I('L*("`@("`@("!R97%U:7)E(%!!4CHZ2&5A=GD[
M"B`@("`@("`@4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PH@("`@
M("`@(&EN:71?:6YC*"D["@H@("`@("`@(')E<75I<F5?;6]D=6QE<R@I.PH*
M("`@("`@("!M>2!`:6YC(#T@<V]R="!["B`@("`@("`@("`@(&QE;F=T:"@D
M8BD@/#T^(&QE;F=T:"@D82D*("`@("`@("!](&=R97`@>PH@("`@("`@("`@
M("`A+T)31%!!3B\*("`@("`@("!](&=R97`@>PH@("`@("`@("`@("`H)&)U
M;F1L92!N92`G<VET92<I(&]R"B`@("`@("`@("`@("@D7R!N92`D0V]N9FEG
M.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B`@("`@("`@("`@("`D7R!N92`D
M0V]N9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PH@("`@("`@('T@0$E.0SL*
M"B`@("`@("`@(R!&:6QE(&5X:7-T<R!T97-T(&%D9&5D('1O(&9I>"!25"`C
M-#$W.3`Z"B`@("`@("`@(R!&=6YN>2P@;F]N+65X:7-T:6YG(&5N=')Y(&EN
M(%\\+BXN+F%U=&\O0V]M<')E<W,O4F%W+UIL:6(O875T;W-P;&ET+FEX+@H@
M("`@("`@(",@5&AI<R!I<R!A(&)A;F0M86ED(&9I>"!W:71H(&YO(&1E97!E
M<B!G<F%S<"!O9B!T:&4@:7-S=64N"B`@("`@("`@(R!3;VUE8F]D>2!P;&5A
M<V4@9V\@=&AR;W5G:"!T:&4@<&%I;B!O9B!U;F1E<G-T86YD:6YG('=H870G
M<R!H87!P96YI;F<L"B`@("`@("`@(R!)(&9A:6QE9"X@+2T@4W1E9F9E;@H@
M("`@("`@(&UY("5F:6QE<SL*("`@("`@("`O7E\\*"XK*20O(&%N9"`M92`D
M,2!A;F0@)&9I;&5S>R0Q?2LK(&9O<B!K97ES("4Z.CL*("`@("`@("`D9FEL
M97-[)%]]*RL@9F]R('9A;'5E<R`E24Y#.PH*("`@("`@("!M>2`D;&EB7V5X
M="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*("`@("`@("!M>2`E=W)I
M='1E;CL*"B`@("`@("`@9F]R96%C:"`H<V]R="!K97ES("5F:6QE<RD@>PH@
M("`@("`@("`@("!M>2`H)&YA;64L("1F:6QE*3L*"B`@("`@("`@("`@(&9O
M<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PH@("`@("`@("`@("`@("`@:68@*"1N
M86UE(#T@)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD7WTI('L*("`@("`@("`@
M("`@("`@("`@("`D9FEL92`]("1?.PH@("`@("`@("`@("`@("`@("`@(&QA
M<W0["B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E;'-I9B`H
M+UXH7%$D9&ER7$5<+R@N*EM>0V-=*2E<6B]I*2!["B`@("`@("`@("`@("`@
M("`@("`@*"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*("`@("`@("`@("`@
M("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@
M("`@96QS:68@*&TA7B]L;V%D97(O6UXO72LO*"XJ6UY#8UTI7%HA*2!["B`@
M("`@("`@("`@("`@("`@("`@:68@*&UY("1R968@/2`D4$%2.CI(96%V>3HZ
M36]D=6QE0V%C:&5[)#%]*2!["B`@("`@("`@("`@("`@("`@("`@("`@("@D
M9FEL92P@)&YA;64I(#T@*"1R968L("0Q*3L*("`@("`@("`@("`@("`@("`@
M("`@("`@;&%S=#L*("`@("`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@
M("`@("`@("`@96QS:68@*"UF("(D9&ER+R0Q(BD@>PH@("`@("`@("`@("`@
M("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L("0Q*3L*
M("`@("`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@("`@
M("`@("!]"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@('T*"B`@("`@
M("`@("`@(&YE>'0@=6YL97-S(&1E9FEN960@)&YA;64@86YD(&YO="`D=W)I
M='1E;GLD;F%M97TK*SL*("`@("`@("`@("`@;F5X="!I9B`A<F5F*"1F:6QE
M*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"\["B`@("`@("`@("`@
M(&]U=',H(&IO:6X@(B(L"B`@("`@("`@("`@("`@("!Q<2A086-K:6YG("(I
M+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L"B`@("`@("`@
M("`@("`@("!Q<2@B+BXN*0H@("`@("`@("`@("`I.PH*("`@("`@("`@("`@
M;7D@)&-O;G1E;G0["B`@("`@("`@("`@(&EF("AR968H)&9I;&4I*2!["B`@
M("`@("`@("`@("`@("`D8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*("`@("`@
M("`@("`@?0H@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@("`@(&]P
M96X@1DE,12P@)SPG+"`D9FEL92!O<B!D:64@(D-A;B=T(&]P96X@)&9I;&4Z
M("0A(CL*("`@("`@("`@("`@("`@(&)I;FUO9&4H1DE,12D["B`@("`@("`@
M("`@("`@("`D8V]N=&5N="`](#Q&24Q%/CL*("`@("`@("`@("`@("`@(&-L
M;W-E($9)3$4["@H@("`@("`@("`@("`@("`@4$%2.CI&:6QT97(Z.E!O9%-T
M<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4I"B`@("`@("`@("`@
M("`@("`@("`@:68@(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@
M+UPN*#\Z<&U\:7A\86PI)"]I.PH*("`@("`@("`@("`@("`@(",@1&\@;F]T
M(&QE="!84TQO861E<B!P:6-K('5P(&%U=&\O*B!F<F]M(&5N=FER;VYM96YT
M"B`@("`@("`@("`@("`@("`D8V]N=&5N="`]?B!S+V=O=&\@*W)E=')Y("MU
M;FQE<W,@*RXJ+V=O=&\@<F5T<GD[+PH@("`@("`@("`@("`@("`@("`@(&EF
M(&QC*"1N86UE*2!E<2!L8R@B6%-,;V%D97(N<&TB*3L*("`@("`@("`@("`@
M?0H*("`@("`@("`@("`@;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*
M("`@("`@("`@("`@)&9H+3YP<FEN="@B1DE,12(I.PH@("`@("`@("`@("`D
M9F@M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI.PH@("`@
M("`@("`@("`D9F@M/G!R:6YT*'-P<FEN=&8H"B`@("`@("`@("`@("`@("`B
M)3`X>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT
M*2P@)&YA;64*("`@("`@("`@("`@*2D["B`@("`@("`@("`@("1F:"T^<')I
M;G0H<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI*3L*("`@("`@("`@("`@
M)&9H+3YP<FEN="@D8V]N=&5N="D["B`@("`@("`@?0H@("`@?0H@("`@(R!]
M?7T*"B`@("`C($YO=R!W<FET92!O=70@=&AE(%!!4B!A;F0@;6%G:6,@<W1R
M:6YG<R![>WL*("`@("1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@
M)'II<#L*"B`@("`D8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@
M,"P@-#`["B`@("!I9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H
M<W1A="@D;W5T*2E;.5TI('L*("`@("`@("!M>2`D8W1X(#T@979A;"![(')E
M<75I<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0H@("`@
M("`@("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S
M=#HZ4TA!,2T^;F5W('T*("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@
M1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*"B`@("`@("`@(R!7
M;W)K87)O=6YD(&9O<B!B=6<@:6X@1&EG97-T.CI32$$@-2XS."!A;F0@-2XS
M.0H@("`@("`@(&UY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI3
M2$$Z.E9%4E-)3TX@?2!\?"`P.PH@("`@("`@(&EF("@D<VAA7W9E<G-I;VX@
M97$@)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*("`@("`@
M("`@("`@)&-T>"T^861D9FEL92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*("`@
M("`@("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@(&EF("@D8W1X(&%N
M9"!O<&5N*&UY("1F:"P@(CPD;W5T(BDI('L*("`@("`@("`@("`@("`@(&)I
M;FUO9&4H)&9H*3L*("`@("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)&9H
M*3L*("`@("`@("`@("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@("`@('T*
M("`@("`@("!]"@H@("`@("`@("1C86-H95]N86UE(#T@)&-T>"`_("1C='@M
M/FAE>&1I9V5S="`Z("1M=&EM93L*("`@('T*("`@("1C86-H95]N86UE("X]
M(")<,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I.PH@("`@)&-A8VAE
M7VYA;64@+CT@(D-!0TA%(CL*("`@("1F:"T^<')I;G0H)&-A8VAE7VYA;64I
M.PH@("`@)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H
M*"1L;V%D97(I*2D["B`@("`D9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B`@
M("`D9F@M/F-L;W-E.PH@("`@8VAM;V0@,#<U-2P@)&]U=#L*("`@(",@?7U]
M"@H@("`@97AI=#L*?0HC('U]?0H*(R!0<F5P87)E("1P<F]G;F%M92!I;G1O
M(%!!4B!F:6QE(&-A8VAE('M[>PI["B`@("!L87-T('5N;&5S<R!D969I;F5D
M("1S=&%R=%]P;W,["@H@("`@7V9I>%]P<F]G;F%M92@I.PH*("`@(",@3F]W
M(&QO860@=&AE(%!!4B!F:6QE(&%N9"!P=70@:70@:6YT;R!005(Z.DQI8D-A
M8VAE('M[>PH@("`@<F5Q=6ER92!005(["B`@("!005(Z.DAE879Y.CI?:6YI
M=%]D>6YA;&]A9&5R*"D["@H*("`@('L*("`@("`@("`C;&]C86P@)$E.0WLG
M0W=D+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@
M("`@(')E<75I<F4@1FEL93HZ1FEN9#L*("`@("`@("!R97%U:7)E($%R8VAI
M=F4Z.EII<#L*("`@('T*("`@(&UY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE
M=SL*("`@(&UY("1F:"`]($E/.CI&:6QE+3YN97<["B`@("`D9F@M/F9D;W!E
M;BAF:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D0"(["B`@("`D>FEP
M+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI
M=F4Z.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["@H@("`@<'5S:"!`
M4$%2.CI,:6)#86-H92P@)'II<#L*("`@("1005(Z.DQI8D-A8VAE>R1P<F]G
M;F%M97T@/2`D>FEP.PH*("`@("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT[
M"B`@("!O=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0
M?2(I*3L*"B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H
M;W5L9"!B92!S970@870@=&AI<R!P;VEN="$*("`@("`@("!F;W)E86-H(&UY
M("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PH@("`@("`@("`@("!N97AT
M(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PH@("`@("`@("`@("!M>2`D;65M
M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*("`@("`@("`@("`@;F5X
M="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["B`@("`@("`@("`@("`@("!>
M"B`@("`@("`@("`@("`@("`O/W-H;&EB+PH@("`@("`@("`@("`@("`@*#\Z
M)$-O;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B`@("`@("`@("`@("`@("`H
M/SHD0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"B`@("`@("`@("`@("`@
M("`H6UXO72LI"B`@("`@("`@("`@("`@("`D"B`@("`@("`@("`@('UX.PH@
M("`@("`@("`@("!M>2`D97AT<F%C=%]N86UE(#T@)#$["B`@("`@("`@("`@
M(&UY("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%2
M7U1%35!]+"`D97AT<F%C=%]N86UE*3L*("`@("`@("`@("`@:68@*"UF("1D
M97-T7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE
M*"DI('L*("`@("`@("`@("`@("`@(&]U=',H<7$H4VMI<'!I;F<@(B1M96UB
M97)?;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA
M;64B*2D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!O
M=71S*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA
M;64B*2D["B`@("`@("`@("`@("`@("`D;65M8F5R+3YE>'1R86-T5&]&:6QE
M3F%M960H)&1E<W1?;F%M92D["B`@("`@("`@("`@("`@("!C:&UO9"@P-34U
M+"`D9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PH@("`@("`@("`@("!]
M"B`@("`@("`@?0H@("`@?0H@("`@(R!]?7T*?0HC('U]?0H*(R!)9B!T:&5R
M92=S(&YO(&UA:6XN<&P@=&\@<G5N+"!S:&]W('5S86=E('M[>PIU;FQE<W,@
M*"1005(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*("`@(&1I92`\/"`B+B(@
M=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER
M(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B`@
M("`@("`D,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B`@("`D
M14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!
M4D=6*3L*?0HC('U]?0H*<W5B($-R96%T95!A=&@@>PH@("`@;7D@*"1N86UE
M*2`]($!?.PH@("`@"B`@("!R97%U:7)E($9I;&4Z.D)A<V5N86UE.PH@("`@
M;7D@*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z
M.F9I;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PH@("`@"B`@("!R97%U:7)E
M($9I;&4Z.E!A=&@["B`@("`*("`@($9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T
M:"D@=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R
M"GT*"G-U8B!R97%U:7)E7VUO9'5L97,@>PH@("`@(VQO8V%L("1)3D-[)T-W
M9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*"B`@("!R
M97%U:7)E(&QI8CL*("`@(')E<75I<F4@1'EN84QO861E<CL*("`@(')E<75I
M<F4@:6YT96=E<CL*("`@(')E<75I<F4@<W1R:6-T.PH@("`@<F5Q=6ER92!W
M87)N:6YG<SL*("`@(')E<75I<F4@=F%R<SL*("`@(')E<75I<F4@0V%R<#L*
M("`@(')E<75I<F4@0V%R<#HZ2&5A=GD["B`@("!R97%U:7)E($5R<FYO.PH@
M("`@<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["B`@("!R97%U:7)E($5X<&]R
M=&5R.PH@("`@<F5Q=6ER92!&8VYT;#L*("`@(')E<75I<F4@1FEL93HZ5&5M
M<#L*("`@(')E<75I<F4@1FEL93HZ4W!E8SL*("`@(')E<75I<F4@6%-,;V%D
M97(["B`@("!R97%U:7)E($-O;F9I9SL*("`@(')E<75I<F4@24\Z.DAA;F1L
M93L*("`@(')E<75I<F4@24\Z.D9I;&4["B`@("!R97%U:7)E($-O;7!R97-S
M.CI:;&EB.PH@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!R97%U:7)E
M(%!!4CL*("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@(')E<75I<F4@4$%2
M.CI$:7-T.PH@("`@<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["B`@
M("!R97%U:7)E(&%T=')I8G5T97,["B`@("!E=F%L('L@<F5Q=6ER92!#=V0@
M?3L*("`@(&5V86P@>R!R97%U:7)E(%=I;C,R('T["B`@("!E=F%L('L@<F5Q
M=6ER92!38V%L87(Z.E5T:6P@?3L*("`@(&5V86P@>R!R97%U:7)E($%R8VAI
M=F4Z.E5N>FEP.CI"=7)S="!].PH@("`@979A;"![(')E<75I<F4@5&EE.CI(
M87-H.CI.86UE9$-A<'1U<F4@?3L*("`@(&5V86P@>R!R97%U:7)E(%!E<FQ)
M3SL@<F5Q=6ER92!097)L24\Z.G-C86QA<B!].PI]"@HC(%1H92!#('9E<G-I
M;VX@;V8@=&AI<R!C;V1E(&%P<&5A<G,@:6X@;7EL9'(O;6MT;7!D:7(N8PHC
M(%1H:7,@8V]D92!A;'-O(&QI=F5S(&EN(%!!4CHZ4V5T=7!496UP(&%S('-E
M=%]P87)?=&5M<%]E;G8A"G-U8B!?<V5T7W!A<E]T96UP('L*("`@(&EF("AD
M969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O
M*"XK*2\I('L*("`@("`@("`D<&%R7W1E;7`@/2`D,3L*("`@("`@("!R971U
M<FX["B`@("!]"@H@("`@9F]R96%C:"!M>2`D<&%T:"`H"B`@("`@("`@*&UA
M<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-
M4"!435`@*2DL"B`@("`@("`@<7<H($,Z7%Q414U0("]T;7`@+B`I"B`@("`I
M('L*("`@("`@("!N97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D
M<&%T:"!A;F0@+7<@)'!A=&@["B`@("`@("`@;7D@)'5S97)N86UE.PH@("`@
M("`@(&UY("1P=W5I9#L*("`@("`@("`C(&1O97,@;F]T('=O<FL@979E<GEW
M:&5R93H*("`@("`@("!E=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I
M9B!D969I;F5D("0^.WT["@H@("`@("`@(&EF("@@9&5F:6YE9"@F5VEN,S(Z
M.DQO9VEN3F%M92D@*2!["B`@("`@("`@("`@("1U<V5R;F%M92`]("97:6XS
M,CHZ3&]G:6Y.86UE.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H9&5F:6YE
M9"`D<'=U:60I('L*("`@("`@("`@("`@)'5S97)N86UE(#T@)'!W=6ED.PH@
M("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@)'5S97)N86UE
M(#T@)$5.5GM54T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*
M("`@("`@("!]"B`@("`@("`@)'5S97)N86UE(#U^(',O7%<O7R]G.PH*("`@
M("`@("!M>2`D<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTD
M=7-E<FYA;64B.PH@("`@("`@(&UK9&ER("1S=&UP9&ER+"`P-S4U.PH@("`@
M("`@(&EF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A
M="@D<')O9VYA;64I*5LY72D@>PH@("`@("`@("`@("!O<&5N("AM>2`D9F@L
M("(\(BX@)'!R;V=N86UE*3L*("`@("`@("`@("`@<V5E:R`D9F@L("TQ."P@
M,CL*("`@("`@("`@("`@<WES<F5A9"`D9F@L(&UY("1B=68L(#8["B`@("`@
M("`@("`@(&EF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PH@("`@("`@("`@("`@
M("`@<V5E:R`D9F@L("TU."P@,CL*("`@("`@("`@("`@("`@('-Y<W)E860@
M)&9H+"`D8G5F+"`T,3L*("`@("`@("`@("`@("`@("1B=68@/7X@<R]<,"\O
M9SL*("`@("`@("`@("`@("`@("1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI
M;7UC86-H92TB("X@)&)U9CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E
M;'-E('L*("`@("`@("`@("`@("`@(&UY("1C='@@/2!E=F%L('L@<F5Q=6ER
M92!$:6=E<W0Z.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"B`@("`@("`@
M("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$
M:6=E<W0Z.E-(03$M/FYE=R!]"B`@("`@("`@("`@("`@("`@("`@?'P@979A
M;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*
M"B`@("`@("`@("`@("`@("`C(%=O<FMA<F]U;F0@9F]R(&)U9R!I;B!$:6=E
M<W0Z.E-(02`U+C,X(&%N9"`U+C,Y"B`@("`@("`@("`@("`@("!M>2`D<VAA
M7W9E<G-I;VX@/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@
M,#L*("`@("`@("`@("`@("`@(&EF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G
M(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*("`@("`@("`@("`@("`@
M("`@("`D8W1X+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D[
M"B`@("`@("`@("`@("`@("!]"B`@("`@("`@("`@("`@("!E;'-E('L*("`@
M("`@("`@("`@("`@("`@("!I9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\
M)'!R;V=N86UE(BDI('L*("`@("`@("`@("`@("`@("`@("`@("`@8FEN;6]D
M92@D9F@I.PH@("`@("`@("`@("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE
M*"1F:"D["B`@("`@("`@("`@("`@("`@("`@("`@(&-L;W-E*"1F:"D["B`@
M("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H*("`@("`@
M("`@("`@("`@("1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB
M("X@*"`D8W1X(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE("D["B`@("`@
M("`@("`@('T*("`@("`@("`@("`@8VQO<V4H)&9H*3L*("`@("`@("!]"B`@
M("`@("`@96QS92!["B`@("`@("`@("`@("1%3E9[4$%27T-,14%.?2`](#$[
M"B`@("`@("`@("`@("1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP
M+20D(CL*("`@("`@("!]"@H@("`@("`@("1%3E9[4$%27U1%35!](#T@)'-T
M;7!D:7(["B`@("`@("`@;6MD:7(@)'-T;7!D:7(L(#`W-34["B`@("`@("`@
M;&%S=#L*("`@('T*"B`@("`D<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]4
M14U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"@IS=6(@7W1E
M;7!F:6QE('L*("`@(&UY("@D97AT+"`D8W)C*2`]($!?.PH@("`@;7D@*"1F
M:"P@)&9I;&5N86UE*3L*"B`@("`D9FEL96YA;64@/2`B)'!A<E]T96UP+R1C
M<F,D97AT(CL*"B`@("!I9B`H)$5.5GM005)?0TQ%04Y]*2!["B`@("`@("`@
M=6YL:6YK("1F:6QE;F%M92!I9B`M92`D9FEL96YA;64["B`@("`@("`@<'5S
M:"!`=&UP9FEL92P@)&9I;&5N86UE.PH@("`@?0H@("`@96QS92!["B`@("`@
M("`@<F5T=7)N("AU;F1E9BP@)&9I;&5N86UE*2!I9B`H+7(@)&9I;&5N86UE
M*3L*("`@('T*"B`@("!O<&5N("1F:"P@)SXG+"`D9FEL96YA;64@;W(@9&EE
M("0A.PH@("`@8FEN;6]D92@D9F@I.PH@("`@<F5T=7)N*"1F:"P@)&9I;&5N
M86UE*3L*?0H*(R!S86UE(&-O9&4@;&EV97,@:6X@4$%2.CI3971U<%!R;V=N
M86UE.CIS971?<')O9VYA;64*<W5B(%]S971?<')O9VYA;64@>PH@("`@:68@
M*&1E9FEN960@)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'
M3D%-17T@/7X@+R@N*RDO*2!["B`@("`@("`@)'!R;V=N86UE(#T@)#$["B`@
M("!]"@H@("`@)'!R;V=N86UE('Q\/2`D,#L*"B`@("!I9B`H)$5.5GM005)?
M5$5-4'T@86YD(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X]
M(#`I('L*("`@("`@("`D<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R
M:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["B`@("!]
M"@H@("`@:68@*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N
M86UE+"`D0V]N9FEG>U]D96QI;7TI(#X](#`I('L*("`@("`@("!I9B`H;W!E
M;B!M>2`D9F@L("<\)RP@)'!R;V=N86UE*2!["B`@("`@("`@("`@(')E='5R
M;B!I9B`M<R`D9F@["B`@("`@("`@?0H@("`@("`@(&EF("@M<R`B)'!R;V=N
M86UE)$-O;F9I9WM?97AE?2(I('L*("`@("`@("`@("`@)'!R;V=N86UE("X]
M("1#;VYF:6=[7V5X97T["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]
M"B`@("!]"@H@("`@9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG
M>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PH@("`@("`@(&YE>'0@:68@
M97AI<W1S("1%3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%
M35!].PH@("`@("`@("1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O
M.PH@("`@("`@("@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD
M<')O9VYA;64D0V]N9FEG>U]E>&5](BDL(&QA<W0I"B`@("`@("`@("`@(&EF
M("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE
M?2(["B`@("`@("`@*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM
M?21P<F]G;F%M92(I+"!L87-T*0H@("`@("`@("`@("!I9B`M<R`B)&1I<B1#
M;VYF:6=[7V1E;&EM?21P<F]G;F%M92(["B`@("!]"GT*"G-U8B!?9FEX7W!R
M;V=N86UE('L*("`@("0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'
M3D%-17T["B`@("!I9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI
M;7TI(#P@,"D@>PH@("`@("`@("1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L
M:6U])'!R;V=N86UE(CL*("`@('T*"B`@("`C(%A86"`M(&AA8VL@=&\@;6%K
M92!05T0@=V]R:PH@("`@;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W
M9"D@/R!#=V0Z.F=E=&-W9"@I"B`@("`@("`@("`@("`@("`Z("@H9&5F:6YE
M9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D[
M"B`@("!C:&]M<"@D<'=D*3L*("`@("1P<F]G;F%M92`]?B!S+UXH/SU<+EPN
M/UQ1)$-O;F9I9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO.PH*
M("`@("1%3E9[4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0H*<W5B(%]P
M87)?:6YI=%]E;G8@>PH@("`@:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK
M*R`]/2`Q("D@>PH@("`@("`@(')E='5R;CL*("`@('T@96QS92!["B`@("`@
M("`@)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*("`@('T*"B`@("!F;W(@
M*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@
M05)'0R!!4D=67S`@*2`I('L*("`@("`@("!D96QE=&4@)$5.5GLG4$%27R<N
M)%]].PH@("`@?0H@("`@9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"
M54<@+RD@>PH@("`@("`@("1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'
M3$]"04Q?)RXD7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT[
M"B`@("!]"@H@("`@;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?
M7R`@("`@("`@("`@("`@("(["@H@("`@:68@*"1%3E9[4$%27U1%35!]*2![
M"B`@("`@("`@9&5L971E("1%3E9[4$%27T-,14%.?3L*("`@('T*("`@(&5L
M<VEF("@A97AI<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*("`@("`@
M("!M>2`D=F%L=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H
M(D-,14%.(BDI.PH@("`@("`@("1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V
M86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["B`@("!]"GT*"G-U8B!O=71S
M('L*("`@(')E='5R;B!I9B`D<75I970["B`@("!I9B`H)&QO9V9H*2!["B`@
M("`@("`@<')I;G0@)&QO9V9H(")`7UQN(CL*("`@('T*("`@(&5L<V4@>PH@
M("`@("`@('!R:6YT(")`7UQN(CL*("`@('T*?0H*<W5B(&EN:71?:6YC('L*
M("`@(')E<75I<F4@0V]N9FEG.PH@("`@<'5S:"!`24Y#+"!G<F5P(&1E9FEN
M960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*("`@("`@("!A<F-H
M;&EB97AP('!R:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`H@("`@
M("`@('9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"B`@("`I.PI]"@HC(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,*(R!4:&4@;6%I;B!P86-K86=E(&9O
M<B!S8W)I<'0@97AE8W5T:6]N"@IP86-K86=E(&UA:6X["@IR97%U:7)E(%!!
M4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T
M*$!P87)?87)G<RD["@ID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@
M<V-R:7!T("(D<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y
M7&XI"B`@("!U;FQE<W,@+64@)'!R;V=N86UE.PH*9&\@)'!R;V=N86UE.PI#
M3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I
M.PID:64@)$`@:68@)$`["@I].PH*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]
M"@I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?
M7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["@HQ
M.PH*(VQI;F4@,3`Q,@H*7U]%3D1?7PH```!P87(N<&P``(:R`8&PL*\'````
M``BQ`8&PL`"$`````,RR`8&PL*\_`````(*R`8&PL*\'``````BQ`8&PL%^$
M`````)1M_W\!````D'S_?ZD(L8!`?O]_L*P;@%A__W^I"+&`['__?P$```#$
M@?]_L+"H@/"!_W\`A`*`2(+_?P$````8@_]_@/__?P2%_W\!````2(C_?WS_
M_W]8B/]_`0```$R)_W]X__]_N)+_?WS__W]@E_]_`0```-27_W^PL*B`#)C_
M?["J!8!8FO]_L+"@@'R:_W]@__]_W)K_?["PL(#8FO]_`0``````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````!TG```6)P````````!`````0````$```"M`@```0```+P"
M```!````R`(```$```#3`@```0```-T"```!````ZP(```$```#X`@```0``
M`$<#```!````DP0```$```"S!```#P```"D%```,`````)@```T```#`S@``
M&0````"P`0`;````!````!H````$L`$`'`````0```#U_O]OC($```4````\
MC0``!@```'R%```*````FP8```L````0````%0`````````#````3+$!``(`
M``"0`@``%````!$````7````<)4``!$```!0E0``$@```"`````3````"```
M`/[__V_0E```____;P0```#P__]OV),`````````````````````````````
M``````````````````````````````````````RP`0````````````R8```,
MF```#)@```R8```,F```#)@```R8```,F```#)@```R8```,F```#)@```R8
M```,F```#)@```R8```,F```#)@```R8```,F```#)@```R8```,F```#)@`
M``R8```,F```#)@```R8```,F```#)@```R8```,F```#)@```R8```,F```
M#)@```R8```,F```#)@```R8```,F```#)@```R8```,F```#)@```R8```,
MF```#)@```R8```,F```#)@```R8```,F```#)@```R8```,F```#)@```R8
M```,F```#)@```R8```,F```#)@```R8```,F```#)@```R8```,F```#)@`
M``R8```,F```#)@```R8```,F```#)@```R8```,F```#)@```R8```,F```
M#)@```R8`````````````/____\@+@$`Z5L``$$H````865A8FD``1X````%
M-51%``8$"`$)`1($%`$5`1<#&`$9`1H"1T-#.B`H1TY5*2`T+C4N,2`R,#$P
M,#DR-"`H4F5D($AA="`T+C4N,2TT*0``+G-H<W1R=&%B`"YI;G1E<G``+FYO
M=&4N04))+71A9P`N;F]T92YG;G4N8G5I;&0M:60`+F=N=2YH87-H`"YD>6YS
M>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`+G)E;"YD
M>6X`+G)E;"YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N05)-+F5X
M=&%B`"Y!4DTN97AI9'@`+F5H7V9R86UE`"YI;FET7V%R<F%Y`"YF:6YI7V%R
M<F%Y`"YJ8W(`+F1Y;F%M:6,`+F=O=``N9&%T80`N8G-S`"Y!4DTN871T<FEB
M=71E<P`N8V]M;65N=```````````````````````````````````````````
M```````````````+`````0````(````T@0``-`$``!,```````````````$`
M````````$P````<````"````2($``$@!```@```````````````$````````
M`"$````'`````@```&B!``!H`0``)```````````````!``````````T````
M]O__;P(```",@0``C`$``/`#```%``````````0````$````/@````L````"
M````?(4``'P%``#`!P``!@````$````$````$````$8````#`````@```#R-
M```\#0``FP8``````````````0````````!.````____;P(```#8DP``V!,`
M`/@````%``````````(````"````6P```/[__V\"````T)0``-`4``"`````
M!@````0````$`````````&H````)`````@```%"5``!0%0``(`````4`````
M````!`````@```!S````"0````(```!PE0``<!4``)`"```%````#`````0`
M```(````?`````$````&`````)@````8```,```````````````$````````
M`'<````!````!@````R8```,&```[`,`````````````!`````0```""````
M`0````8```#XFP``^!L``,@R``````````````0`````````B`````$````&
M````P,X``,!.```(```````````````$`````````(X````!`````@```,C.
M``#(3@``8%\`````````````!`````````"6`````0````(````H+@$`**X`
M`#P```````````````0`````````H0````$``'""````9"X!`&2N``"H````
M#0`````````$`````````*P````!`````@````PO`0`,KP``!```````````
M````!`````````"V````#@````,`````L`$``+````0```````````````0`
M````````P@````\````#````!+`!``2P```$```````````````$````````
M`,X````!`````P````BP`0`(L```!```````````````!`````````#3````
M!@````,````,L`$`#+```$`!```&``````````0````(````W`````$````#
M````3+$!`$RQ``!8`0`````````````$````!````.$````!`````P```*2R
M`0"DL@``$```````````````!`````````#G````"`````,```"XL@$`M+(`
M`#@0``````````````@`````````[`````,``'```````````+2R```I````
M```````````!`````````/P````!````,`````````#=L@``+```````````
M`````0````$````!`````P``````````````";,```4!``````````````$`
M`````````0````R8```````````,``0````<F```````````#``!````()@`
0``````````P``"1A`"1D````
